#
# spec file for package nautilus
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nautilus
Version:        48.0
Release:        1.1
Summary:        File Manager for the GNOME Desktop
License:        GPL-3.0-or-later AND LGPL-2.1-or-later
Group:          Productivity/File utilities
URL:            https://wiki.gnome.org/Apps/Nautilus
Source0:        %{name}-%{version}.tar.zst
Source1:        set_trusted.desktop
Source2:        set_trusted.sh

# needed for directory ownership
BuildRequires:  dbus-1
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gettext-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  meson >= 0.59.0
BuildRequires:  pkgconfig
BuildRequires:  (python3-dataclasses if python3-base < 3.7)
BuildRequires:  pkgconfig(cloudproviders)
BuildRequires:  pkgconfig(gexiv2) >= 0.14.0
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(gio-2.0) >= 2.79.0
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.79.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.79.0
BuildRequires:  pkgconfig(gmodule-no-export-2.0) >= 2.79.0
BuildRequires:  pkgconfig(gnome-autoar-0) >= 0.3.0
BuildRequires:  pkgconfig(gnome-desktop-4) >= 1.0.0
BuildRequires:  pkgconfig(gsettings-desktop-schemas) >= 42
BuildRequires:  pkgconfig(gstreamer-tag-1.0)
BuildRequires:  pkgconfig(gtk4) >= 4.13.6
BuildRequires:  pkgconfig(libadwaita-1) >= 1.4.0
BuildRequires:  pkgconfig(libportal)
BuildRequires:  pkgconfig(libportal-gtk4)
BuildRequires:  pkgconfig(libseccomp)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.7.8
BuildRequires:  pkgconfig(pango) >= 1.44.4
BuildRequires:  pkgconfig(tinysparql-3.0)
# Needed for tests
BuildRequires:  python3-gobject
BuildRequires:  localsearch
#BuildRequires:  tracker-testutils-3.0
#
Requires:       localsearch
Recommends:     gvfs

%description
Nautilus is the file manager for the GNOME desktop.

%package -n libnautilus-extension4
Summary:        File Manager for the GNOME Desktop -- Extension Library
Group:          System/Libraries
Conflicts:      nautilus-totem < 3.31.91

%description  -n libnautilus-extension4
Nautilus is the file manager for the GNOME desktop.

This package contains the library used by nautilus extensions.

%package -n typelib-1_0-Nautilus-4_0
Summary:        File Manager for the GNOME Desktop -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Nautilus-4_0
Nautilus is the file manager for the GNOME desktop.

This package provides the GObject Introspection bindings for the library
used by nautilus extensions.

%package -n gnome-shell-search-provider-nautilus
Summary:        File Manager for the GNOME Desktop -- Search Provider for GNOME Shell
Group:          Productivity/File utilities
BuildArch:      noarch
Requires:       %{name} = %{version}
Requires:       gnome-shell
Supplements:    (%{name} and gnome-shell)

%description -n gnome-shell-search-provider-nautilus
Nautilus is the file manager for the GNOME desktop.

This package contains a search provider to enable GNOME Shell to get
search results from Files (nautilus)

%package devel
Summary:        File Manager for the GNOME Desktop -- Development Files
Group:          Development/Libraries/GNOME
Requires:       %{name} = %{version}
Requires:       libnautilus-extension4 = %{version}
Requires:       typelib-1_0-Nautilus-4_0 = %{version}

%description devel
Nautilus is the file manager for the GNOME desktop.

This package contains development files for nautilus.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D docs=true \
	-D tests=headless \
	%{nil}
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_prefix}
%if 0%{?sle_version}
install -m0644 -D %{SOURCE1} %{buildroot}%{_sysconfdir}/skel/.config/autostart/set_trusted.desktop
install -m0755 -D %{SOURCE2} %{buildroot}%{_bindir}/set_trusted.sh
%endif

%check
%meson_test

%ldconfig_scriptlets -n libnautilus-extension4

%files
%license LICENSE
%doc NEWS README.md
%{_bindir}/nautilus
%{_bindir}/nautilus-autorun-software
%{_datadir}/applications/*.desktop
%{_datadir}/dbus-1/services/org.freedesktop.FileManager1.service
%{_datadir}/dbus-1/services/org.gnome.Nautilus.service
%{_datadir}/glib-2.0/schemas/org.gnome.nautilus.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.Nautilus*
%{_datadir}/metainfo/org.gnome.Nautilus.metainfo.xml
%{_datadir}/%{name}/
%{_mandir}/man1/nautilus*.1%{?ext_man}
%if 0%{?sle_version}
%{_sysconfdir}/skel/.config/autostart
%{_sysconfdir}/skel/.config/autostart/set_trusted.desktop
%{_bindir}/set_trusted.sh
%endif

%files -n libnautilus-extension4
%{_libdir}/libnautilus-extension.so.4*
%dir %{_libdir}/nautilus
%dir %{_libdir}/nautilus/extensions-4
%{_libdir}/nautilus/extensions-4/*.so

%files -n typelib-1_0-Nautilus-4_0
%{_libdir}/girepository-1.0/Nautilus-4.0.typelib

%files -n gnome-shell-search-provider-nautilus
%dir %{_datadir}/gnome-shell
%dir %{_datadir}/gnome-shell/search-providers
%{_datadir}/gnome-shell/search-providers/org.gnome.Nautilus.search-provider.ini

%files devel
%{_libdir}/*.so
%{_includedir}/*
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/*.gir
%{_datadir}/doc/%{name}/

%files lang -f %{name}.lang

%changelog
* Sun Mar 16 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.0:
  + Reversals: Replace uselocale with Glib gettext variant
  + Bugfixes:
  - Generate thumbnails by order in view
  - Try more icons before using generic fallback
  - Focus filename entry in save mode by default
  - Fix tree view and outdated file info crashes introduced in
    48.rc
  - Use colored icon for filesystem root properties
  - Set search popover row heights
  + Cleanups:
  - Various performance enhancements around sorting, hidden files
    and image decoding
  - Add build summary
  + Fix shell search result order
  + Updated translations.
* Mon Mar  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.rc:
  + Enhancements:
  - Run code formatting in parallel
  - Rework CI image job to freedesktop template
  - Rework and speedup adding of files to view
  - Add basic unit tests for files view
  - Load thumbnail info separate from other file infos
  + Reversals: Revert port of properties dialog to AdwDialog due to
    outstanding issues
  + Bugfixes:
  - Fix app chooser widget sizing
  - Fix free space calculation for archive extraction
  - Fix shell sesrch result order
  - Fix floating bar style when unfocused
  + Cleanups:
  - Rework view switching code of window-slot
  - Use AdwSpinner in floating bar
  + Replace uselocale with Glib gettext variant
  + Fix opening the wrong directory when launching an instance
  + Tweak the floating bar background
  + Various minor UI fixes:
  - dynamically handle hierarchy changes in the path bar
  - Still offer rectangular selection when pressing ctrl and
    shift
  + Lots of cleanup
  + Fix occasional stuck grabs when rubberband selecting
  + Display more info in the progress dialog when preparing
  + Don't warn about mime-type mismatches if the handler is the
    same
  + Add close all windows to spatial window menu
  + Fixed help buttons in the preferences dialog
  + Extension system for emblem, property page, menu item
  + Add a context menu to the tree side pane.
  + Focus the next item after delete in list view
  + Improved the gutter-on-the-right problem.
  + Prefer existing windows from the command line in
    open-in-new-window view.
  + Updated translations.
- Drop pkgconfig(gail-3.0) BuildRequires: Not used nor needed.
* Wed Feb 12 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 48.beta:
  + Enhancements:
  - Improve directory loading performance
  - Use AdwDialog for list view column chooser and properties
    dialog
  - Change tab behavior for the sidebar
  - Create about dialog from appdata
  - Port various dialogs to AdwAlertDialog
  - Keep mount monitor around for caching in gvfs to work
  - Adjust to localsearch changes
  - Hide Trash banner when empty
  - Ellipsize sidebar labels in the middle
  - Add a CONTRIBUTING file
  - Allow removing bookmarks from pathbar
  - Various UI tweaks and label changes
  - Various speedups
  + Bugfixes:
  - Fix unintended grid relayouting on thumbnail loading
  - Fix double a11y presentation of the filename in grid view
  - Keep CI running
  - Fix query editor translation
  - Hide empty extensions list in properties
  - Fix NULL dereference with extensions
  + Cleanups:
  - Improve grid selection implementation
  - Avoid setting up unnecessary directory monitors
  - Replace setlocale hack with uselocale
  - Stop setting invisible menu icons
  + Updated translations.
- Replace deprecated update-desktop-files with desktop-file-utils
  BuildRequires, and drop suse-update-desktop macros.
* Tue Feb  4 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.2:
  + Enhancements:
  - Adopt CI release workflow
  - Speed up batch file deletions
  - Speed up simple recursive search through mount monitors
  + Bugfixes:
  - Fix thumbnails for changed files
  - Fix parent path URIs for remote path
  - Fix potential crashes in directory callbacks
  + Updated translations.
* Mon Dec  9 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1:
  + Enhancements: Speed up thumbnail loading.
  + Bugfixes:
  - Do not force reload when error is present to avoid showing
    auth dialog.
  - Open folder in correct window during a DnD hover.
  - Show username in file properties if name is an empty string.
  - Various a11y fixes.
  - Fix number placement when making new name for directory.
  - Various pathbar fixes.
  - Show alert dialog when a symlink is broken.
  - Fix crashes when opening.
  - Various sidebar fixes.
  - Fix ctrl + scroll to zoom in and out of view.
  + Updated translations.
- Drop revert-post-release-bump.patch: No longer needed.
* Tue Nov 12 2024 dimstar@opensuse.org
- Update to version 47.0+38:
  * gtk/placessidebar: Fix placeholder sometimes being stuck at the bottom
  * pathbar: Remove dir separator in front of some schemes
  * gtk/placessidebar: Don't open insensitive rows
  * gtk/nautilusgtkplacessidebar: Don't start drag timer if row can't be known
  * file-chooser: Focus file name entry when cancelling overwrite
  * list-base: Activate folder to open on drag instead of opening through application
  * properties: Hide extensions list box when empty
  * file: Ignore empty strings for owner name
  * general: Various a11y fixes
  * files-view: Fix leak
  * compress-dialog: Fix name entry activation
  * file-utilities: Ignore extension when making new name for directories
  * pathbar: Stop adding extra space to buttons
  * pathbar: Don't show the pathbar button menu in file chooser
  * ui: Add missing accel labels
  * preferences: Clear weak pointer
  * nautilus-mime-actions: Actually report when a symlink is broken
  * xdp-gnome/externalwindow: Call gtk_init before opening a display
  * xdp-gnome/externalwindow: Override current session with GDK_BACKEND
  * nautilus-properties-window: Set use-markup=False in several rows
* Sat Oct 19 2024 bjorn.lie@gmail.com
- Update to version 47.0+14:
  * nautilus-tag-manager: Drop tinysparql 2to3 migration
  * Updated translations.
* Fri Sep 27 2024 bjorn.lie@gmail.com
- Update to version 47.0+8:
  * sidebarrow: Add appropriate margin and opacity
  * list-base: Fix scroll to zoom
  * list-base: Don't scroll when the ctrl key is held
  * contributing: Add a CONTRIBUTING.md file
  * gschema: Revert accidental new translatable strings
  * Updated translations.
- Add revert-post-release-bump.patch: Since we are using a
  gitcheckout, the metadata fails during tests if we do not set a
  proper iso-date.
* Sun Sep 15 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.0:
  + Enhancements:
  - Show new folder button in Open Folder(s) modes
  - Persist window size for file chooser
  + Bugfixes:
  - Fix grammar error
  - Fix build error
  - Escape toast button mnemonics
  + File chooser fixes:
  - Don't show undo button when suggested name doesn't exist
  - Show filter name more consistently
  - Stop crashing when using "Open Item Location"
  - Fix issue where new folder button disappears
  - Fix flat dropdown styles
  + Updated translations.
* Tue Sep  3 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.rc:
  + Enhancements:
  - Polish the file chooser
  - Implement file chooser "choices" menu
  - Allow extracting bzip2 tar files
  - Allow dropping items into the file chooser
  - Add the background menu to the file chooser
  - Allow vertical scrolling in the pathbar
  - Activate the accept button by default in file chooser
  + Bugfixes:
  - Fix various file chooser crashes
  - Don't hide file chooser filters with long filenames or in
    narrow mode
  - Make sure the pathbar always shows the current folder
  - Fix overlapping filename widget in file chooser
  - Make nautilus previewer work between the main window and file
    chooser
  - Various fixes for file chooser paths and save locations
  - Set focus correctly in file chooser
  - Allow unselecting an item in file chooser
  - Add a tooltip to the network address bar button
  - Disallow conventional DnD into the pathbar in file chooser
    mode
  - Don't overflow window in file chooser
  + Updated translations.
- Build against renamed trackers*: Update dependencies.
* Tue Aug 27 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.beta:
  + Enhancements:
  - Implement file chooser portal and introduce file chooser ui
  - Redesign and modernize the compression dialog
  - Modernize the new folder dialog
  - Replace Search Banner with Search Info Popover
  - Redesign "Other Types" search
  - Port to new adwaita widgets
  - Update emblems with symbolics
  + Bugfixes:
  - Use correct path for email
  - File chooser bug fixes
  - Disable bookmarking the network view
  - Change files view accent to grey
  - Fix dragging on touch devices
  - Misc bugfixes
  + Updated translations.
- Changes from version 47.alpha:
  + Enhancements:
  - Add the Network view
  - Show xdg dirs in sidebar as regular (removable) bookmarks
  - Show sidebar bookmarks before mounts
  - Remove "Other Locations" and show mounts directly on the
    sidebar
  - Improve view performance
  - Use new adw views
  - Improve internal NautilusFile performance
  - Improve ui for progress indicator
  - Improve ui to floating bar
  - Allow staring from the context menu
  - Redesign trash dialog
  - Allow Scripts in flatpak
  - Open mounts in original tab instead of focused tab
  - Allow simultaneous mounting
  + Bugfixes:
  - Create archive with Enter on Compress dialog
  - Accessibility fixes
  - Move focus correctly when item is removed
  - Don't reset permissions when copying from a non-isofs
    readonly filesystem
  - Open correct panel in GNOME Settings for trash settings
  - Disable paste in Trash, Recent, and Starred
  - Fix error when passing invalid location to portals
  - Fix memory leaks
  - Call shutdown() on modules
  - Don't show banners in global search
  - Prevent a crash
  - Keep correct file list order in a DnD
  - Don't display future dates as "Today" or "Yesterday"
  - Prevent freeze
  - Fix broken sort order when switching views
  - Don't irreversibly hide sidebar with touch gesture
  - Don't unnecessarily re-set selection in search
  - Don't scale up images in properties preview
  - Actually drop wayland export handles
  - Fix potentially incorrect file operation
  - Batch rename fix tags, and allow illegal characters
  - Allow xdp to fail
  - Fix typo
  + Cleanups:
  - Use property styling for adw rows
  - Code cleanup
  - Significant refactoring and cleanup to prepare to Nautilus as
    a file chooser
  + Updated translations.
* Mon Aug 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire gettext-devel instead of gettext: allow OBS to
  shortcut through gettext-runtime-mini.
* Mon May 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2:
  + Don't treat future dates as "Today".
  + Fix crashes.
  + Prevent freeze on Audio/Video properties.
  + Don't irreversibly hide sidebar with touch gesture.
  + Don't expose unreadable symbol to screen reader.
  + Fix search selection performance.
  + Fix sorting on grid view.
  + Updated translations.
* Wed May  1 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.1:
  + Bugfixes:
  - Create archive with Enter on Compress dialog.
  - Move focus correctly when item is removed.
  - View performance optimization.
  - Fix crash when compressing a file and a folder.
  - Don't show banners in global search.
  - Preserve permissions when copying from read-only file
    systems.
  - Disable non-working global search from Other Locations.
  + Updated translations.
* Mon Mar 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Bugfixes: Remove char limit on size label in properties dialog.
  + Updated translations.
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Enhancements:
  - Adjust empty status page and progress tooltip strings.
  - Add input hints and purpose properties to entries.
  - Refine operations hover background.
  + Bugfixes:
  - Position loop mounts correctly in the sidebar.
  - Fix internationalization issues.
  - Revert crashes-causing multi-file properties performance
    optimization.
  - Reestablish location signals if location change failed.
  - Fix regression which disallowed dropping files on empty
    folders.
  + Cleanups:
  - Remove architecture-sensitive duplicate filename unit test.
  - Refine Appstream metainfo.
  + Updated translations.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + Postponed: The network view from 46.alpha.1 was deemed to
    require more work
  + Enhancements:
  - Added a global search mode.
  - Use 'text entry' cursor on pathbar hover.
  - Add drop shadow to file property dialog icons.
  - Improve progress info icons and tooltips.
* Mon Jan 29 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha.1:
  + Enhancements:
  - Views can be switched without a folder reload.
  - Operations are listed in the bottom of the sidebar.
  - Network view replaces Other Locations.
  - Mounted drives are shown in the sidebar.
  - Selected files are recorded in back and forward history.
  - Subfolder loading indication.
  - Various view performance improvements.
  - Improved performance of multi-file properties dialog.
  + Updated translations.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha.0+39:
  + Revert "files-view: Set selected files even more efficiently".
  + Revert "view-model: Use binary search to find index".
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + Confirm password when creating protected ZIP archives.
  + Make custom folder icon feature discoverable.
  + Make URI entry discoverable.
  + Allow changing owner/group and any permissions under admin:///.
  + Add detailed date and time format option.
  + Detect copy/move over 4GiB file limit on FAT.
  + Give feedback on completion of quick operations.
  + New-style banners, unstar animation, and other visual
    refinements.
  + Allow Alt+Down to revert more than one Alt+Up.
  + Close overlaid sidebar on location change.
  + Updated translations.
* Wed Dec  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.2.1:
  + Fix a crash in sidebar code
  + Fix build without optional cloudproviders dependency.
* Sun Dec  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.2:
  + Don't crash when reconnecting to remove server.
  + Actually detect unmount on some non-native mounts.
  + Don't crash on image properties.
  + Allow types and sizes in Properties to expand.
  + Don't corrupt toast messages.
  + Updated translations.
* Sun Oct 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.1:
  + Don't crash when opening Properties from admin://*
  + Don't crash on unmount
  + Stop jumping to top when using the Menu key
  + Properly reorder bookmarks by drag and drop
  + Re-add search results when switching view mode
  + Fix compilation on 32-bit musl
  - Fix various leaks and warnings
  + Updated translations.
* Wed Oct  4 2023 bjorn.lie@gmail.com
- Update to version 45.0+12:
  + gtk/placessidebar: Use list box for coordinates translation.
  + list-base: Stop jumping to top on Menu key.
  + Updated translations.
- Switch to source service, explicit commit from the stable branch.
* Sun Sep 17 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 45.0:
  + Updated translations.
* Sat Sep  2 2023 Luciano Santos <luc14n0@opensuse.org>
- Update to version 45.rc:
  + Avoid slowness when many files are selected.
  + Make tooltip and menu for Preferences back button not empty.
  + Revert patch which could cause loss of data.
  + Fix sizing and styling of Visible Columns.
  + Change sidebar title.
  + Updated translations.
* Sun Aug 27 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta2:
  + Feature enhancements:
  - New "Search Everywhere" buttons to expand search scope
  - Modern full-height sidebar layout
  - Refined sidebar sizing and folding treshold
  + Performance enhancements:
  - Flickerless transition into and from search
  - Accelerated generation of multiple thumbnail
  - Avoid DBus-activating other apps when starting
  + Bugfixes:
  - Delete partially copied file on cancelled copy
  - Don't restrict shell search results do %%HOME
  - Don't open trash on drag hover
  - Fix multiple search bugs
  - Avoid crashes on search
  - Fix "sort after rename" regression
  - Fix various styling issues
  - Don't allow to resize Properties too small
  + Maintenance: Disable deprecation warnings, fix other warnings
  + Updated translations.
- Drop fix-Werror-return-type-build-error.patch: Fixed upstream.
* Fri Aug 11 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + Enhancements:
  - Use new navigation view and flat headerbar for Properties
  - Don't switch view mode when searching
  - Don't add search to history stack
  - Optimize view performance when selecting or removing many
    items
  + Bugfixes:
  - Prefent mixed-language date and time labels
  - Multiple starred files view bugfixes
  - Context menu capitalization
  + Maintenance:
  - Replace some eel API with direct GLib API
  - Cleanup URI scheme checking
  - Use newer async API for creating thumbnails
  + Updated translations.
* Fri Jul 28 2023 Luciano Santos <luc14n0@opensuse.org>
- Add fix-Werror-return-type-build-error.patch as a quick fix for a
  build error (‘return’ with a value, in function returning void)
  caught by -Werror=return-type.
* Fri Jul  7 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Enhancements:
  - Boost search performance
  - Redesign Visible Columns options, allow changing default
    columns
  - Support dropping images from web pages
  - Show bytes size as tooltip for folder properties too
  - Indicate starred files in grid view
  - Support skipping errors while creating compressed archives
  - Make date and time format more consistent
  - Make Ctrl+F refocus search bar, not cancel search
  - Adapt sidebar width to window width, and use a breakpoint for
    adaptiveness
  - Allow moving keyboard focus within list rows
  - Replace GtkComboBox with GtkDropDown
  - Simplify Keyboard Shortcuts window definition
  - Improve file opening experience while sandboxed
  + Bugfixes:
  - Fix results ordering, and other search bugs
  - Fix tooltips, a11y labels, and i18n issues
  - Fix sushi integration bugs
  - Don't hide incompletely deleted folders
  - Show file renamed to hidden again on undo
  - Don't state file was "deleted" if it was moved to trash
  - Fix rubberband range behavior on list view
  - Respect modifiers when dropping on tabs; disable broken tab
    drop target on X11
  - Fix bugs when reloading on autofs timeouts
  - Don't offer to format volumes which cannot be formatted, e.g.
    MTP
  - Fix multiple crashes
  - Fix multiple leaks
  + Maintenance:
  - Rename default branch to 'main'
  - Make libcloudproviders dependency optional again
  - Improve reproducibility
  + Updated translations.
- Drop 3a931f61.patch: Fixed upstream.
* Sat Jun 10 2023 Luciano Santos <luc14n0@opensuse.org>
- Add 3a931f61.patch patch to fix crash when closing tabs right
  after clicking.
* Sun May 28 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.2:
  + Fix crashes with expandable folders and on Other Locations.
  + Avoid inconsistent search states.
  + Prevent lingering tracker cursors.
  + Fix rubberband range behavior on list view.
  + Updated translations.
- Drop 0e5b4c34.patch and 6e37d15f.patch: Fixed upstream.
* Sat May 13 2023 Luciano Santos <luc14n0@opensuse.org>
- Drop mount-archive.desktop. This was a feature based on
  FATE#308344 and bgo#602147. However, the provided functionality
  of mounting archives through gvfsd-archive has been broken for a
  long time due to the Exec line pointing to a non-existent path
  (/usr/lib/gvfs/gvfsd-archive, rather than /usr/libexec/...).
  Besides, there is a similar functionality which allow users to
  see the content of archives, without extracting them, through
  File Roller that serves as a replacement.
* Wed May 10 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add upstream bug fix patches:
  + 0e5b4c34.patch general: Use GtkSwitch active property
    consistently. app-chooser sets the state instead of active
    property. Similar to d7af60161d30c885ebab69c58b346896f1565387,
    we really meant to set active (whether the switch is toggled)
    and not the state (i.e. the color of the switch). Use
    gtk_switch_set_active().
    In properties we've already fixed this, but there's a lingering
    call to gtk_switch_get_state(). This is probably fine because
    state is in sync with active when the default handler is used,
    but let's get :active, to be consistent and safe.
  + 6e37d15f.patch window-slot: Manage search props set with
    action. Manages search property change through "search-visible"
    action. The action triggers other related functions that if not
    executed will causes buggy behavior.
    Fixes https://gitlab.gnome.org/GNOME/nautilus/-/issues/2875
* Sun Apr 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Resolve some crashes.
  + Visual bugfixes:
  - Tweak style colors in view items
  - Show custom emblems from extensions again
  - Relayout SELinux property row
  - Flip switches correctly
  + Other bugfixes:
  - Disable some actions when not usefull
  - Fix dead characters handling in batch rename dialog
  - Fix crashes when rapidly opening and closing windows
  - Prevent location change when autofs timeouts
  - Fix issues with translations in libadwaita widgets
  - Drop workarounds for fixed GTK bugs
  - Fix other issues
  + Enhancements:
  - Dismiss toast on undo
  - Select right items after some operations
  - Paste into expanded folders
  - Allow extraction of .tar.zst and .zstd archives
  - Performance optimization
  + Updated translations.
* Fri Mar 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.0:
  + Bugfixes:
  - Prevent rubberband selection instead of drag and drop.
  - Fix critical errors with recent GLib versions.
  + Updated translations.
* Sun Mar  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.rc:
  + Fix crashes caused by extra free call
  + Fix file order after renaming
  + Fix libadwaita include path
  + Fix handling of missing dates from Tracker
  + Cache clock format setting
  + Try to own dbus name at the correct time
  + Exchange mismatched error messages
  + Updated translations.
- Add explicit tracker BuildRequires, now needed for tests due to
  changes in tracker/tracker-miners.
* Fri Feb 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.beta:
  + Enhacements:
  - Make various appdata and desktop file improvements
  - Make rubberband to have rounded corners
  - Make several documentation improvements
  + Bugfixes:
  - Fix crashes caused by inverted g_assert condition
  - Fix various drag and drop issues
  - Fix several memory leaks
  - Fix various three expander issues
  - Export FileManager1 iface from dbus_register vfunc
  - Fix other issues
  + Updated translations.
* Fri Feb 17 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 44.alpha:
  + Enhancements:
  - Allow expanding subfolders in the list.
  - Enrich tab context menus.
  - Allow pasting image data into new PNG file.
  - Use pregenerated thumbnails when available, e.g. MTP.
  - Add shortcut for Preferences.
  - Show full filename in grid, using tooltips.
  - Reintroduce 64px icon size for grid view.
  - Remove upper limit on thumbnailing file size range.
  - Reword "application" to "app".
  - Other papercuts.
  + Other bugfixes:
  - Avoid many crashes.
  - Fix and improve autorun support.
  - Fix some drag-and-drop issues.
  - Fix some view focus and selection issues.
  - Fix properties extensions bugs.
  - Fix memory leaks.
  - Fix building on certain cases.
  - Fix bugs with file operations.
  - Resolve some performance issues.
  - Resolve stuttering scrolling.
  - Save and restore sort column.
  - Reimplement view navigation from the previewer.
  + Updated translations.
* Thu Jan 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.2:
  + Regressions addressed:
  - Launch search from shell correctly
  - Make nautilus-autorun-software work again
  - Restore 2-dimensional navigation from sushi
  - Resolve stuttering scrolling
  - Reintroduce 64px icon size for grid view
  - Show full filename again in grid, using tooltips
  + Other bugfixes:
  - Avoid a many crashes
  - Stop showing � in the type on Properties
  - Show rename error dialogs again
  - Handle X11-only drag-and-drop quirks
  - Allow autorun.sh without executable bit
  - Improve selection-setting
  - Restrict DND actions over drag source
  - Focus replaces files
  - Improve keyboard focus navigation on the new views
  - Stop blocking on the tracker connection
  - Don't add missing emblems
  + Updated translations.
* Fri Dec  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.1:
  + Bugfixes:
  - Actually reset metadata when reseting to default columns
  - Don't allow hiding name column
  - Keep track of column sorting changes
  - Fix view focus navigation
  - Reimplement view navigation from the previewer
  - Don't accept drops into search directory
  - Share settings with GTK4 filechooser
  - Fix a properties extensions bugs
  - Fix various Drag-and-Drop bugs
  - Remove dead shortcut from Keyboard Shortcut
  - Allow opening current view in new tab from sidebar
  - Fix crashes
  + Performance improvements:
  - Optimize sorting during directory loading
  - Minimize column factories
  - Increase search timeout
  - Minimize and optimize menu updates
  + Build fixes: Make header prototypes match definitions
  + Updated translations.
  + Drop upstream merged nautilus-CVE-2022-37290.patch.
* Thu Dec  1 2022 Yifan Jiang <yfjiang@suse.com>
- Add nautilus-CVE-2022-37290.patch to fix the CVE-2022-37290
  (bsc#1205418).
* Wed Oct 12 2022 Atri Bhattacharya <badshah400@gmail.com>
- Drop nautilus-revert-extra-large-thumbnails.patch: No longer
  needed with glib2 2.74.1.
* Sat Sep 24 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add nautilus-revert-extra-large-thumbnails.patch: Revert
  "thumbnails: Create larger thumbnails for higher density
  displays"; patch taken from upstream merge request
  (glgo#GNOME/nautilus#2487, boo#1203697).
* Sun Sep 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.0:
  + Bugs fixed:
  - Open first search result with Enter, as before.
  - Don't freeze when opening media storage.
  + Updated translations.
* Mon Sep  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 43.rc:
  + Resolving regressions from the GTK 3 to 4 switch:
  - Restore accessible labels for view items/.
  - HiDPI icons and thumbnails.
  - Restore transient location entry behavior.
  - Restore spacebar shortcut to trigger sushi file previewer.
  - Restore ability to create new file from dropped text.
  - Restore ability to duplicate via DND + Ctrl.
  + Drag-and-drop enhancements:
  - Allow dropping files into Starred to star them.
  - Prevent "open on hover" while moving pointer.
  + Menu enhancements:
  - Add menu item to remove files from Starred list.
  - Don't activate menu button when clicking folder name.
  - Don't offer "Properties" and "Add to Bookmarks" actions when
    they don't make sense.
  + Properties enhancements:
  - Wrap long filename words in Properties.
  - Refine properties for root directory.
  - Show error state for extensions properties.
  + General enhancements:
  - Redesign trash infobar.
  - Add tooltips to every headerbar control.
  - Update and modernize libnautilus-extension documentation.
  - Update appdata screenshots.
  + Bugfixes:
  - Fix various app chooser issues.
  - Fix various batch rename dialog issues.
  - Fix Highcontrast styles.
  - Fix focus misbehaviours in the new views.
  - Don't show URI escape codes in tooltips.
  - Show sharing infobar in gnome-user-share's fallback location.
  - Fix icon size in file conflict dialog.
  - Fix operations indicator animation.
  - Mark missing translatable strings.
  - Fix various memory leaks.
  - Fix compilation errors.
  + Updated translations.
- Replace gtk-doc BuildRequires for pkgconfig(gi-docgen): follow
  upstreams move to gi-docgen.
- Mark gnome-shell-search-provider-nautilus noarch.
* Mon Aug  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta.1:
  + Restore view options tooltip
  + Mark new files for translation
  + Look for extensions in their new installation directory
- Stop creating 3.0 extensions directory, and bump soversion on
  what we currently support and build.
* Sun Aug  7 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.beta:
  + Adapting main window elements to smaller sizes;
  - Make sidebar foldable.
  - Split toolbar contorls into top and bottom toolbars at small
    sizes.
  + Restoring Disks integration:
  - Open storage unit in Disks from Properties.
  - Format with Disks from the sidebar context menu.
  + Absorbing features from core plug-ins:
  - Provide infobar for Public folder, instead of
    gnome-user-share.
  - Provide context menu action to open folders in Console.
  - Replace nautilus-send-to extension with Email portal.
  + Remodeling plug-ins
  - List installed extensions plug-ins in About.
  - Implement new Properties API and port Image and Audio/Video.
  - Remove GTK-dependent API from libnautilus-extension.
  - Bump libnautilus-extension versions.
  + Improving search UI design
  - Use modern design patterns for type filter chooser.
  - Elaborate FTS snippets and place them in a container.
  + Modernizing Properties window
  - Implement new "pages and rows" design.
  - Move ability to set default app into Open With dialog.
  + Reorganizing context menus.
  + Refining view visual styles
  - Saturate selection colors.
  - Add icon shadows.
  - Refine layout of column editor dialog.
  + Using more modern widgetry:
  - Use AdwTabBar for detatchable tabs.
  - Use AdwEmptyState for empty folder views.
  - Use AdwMessageDialog instead of GtkMessage.
  + Resolving regressions from the GTK 3 to 4 switch:
  - Restore Accessibility relations.
  - Restore location entry suggestions.
  - Restore libcloudproviders integration.
  + Opening new tab with middle click on next and forward buttons.
  + Miscellaneous bugfixes.
  + Leftover known regressions in 43.beta:
  - Lacks HiDPI icons.
  - Lacks attention-grabbing animation on operations button.
  + Updated translations.
- Add pkgconfig(cloudproviders) BuildRequires: New dependency.
- Rename libnautilus-extension2 to libnautilus-extension4 following
  upstreams soname changes.
* Sat Aug  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 43.alpha:
  + Resolving regressions from the GTK 3 to 4 switch:
  - Reintroduce clipboard with GTK 4
  - Reintroduce Drag’n’Drop with GTK 4
  - Reintroduce emblems independently of file icon
  - Reintroduce filter search tags with GTK 4
  - Port audio-video-properties extension to GTK 4
  - Restore sidebar features from GTK 3
  - Fix other regressions from the GTK 3 to 4 switch
  + Modernizing view widgets:
  - Port files grid view mode to GtkGridView
  - Reimplement files list view mode with GtkColumnView
  - Add checkerboard background for thumbnails with transparency
  + Enhancing menus:
  - New menu item to open current folder in another application
  - Add menu item to copy current path to clipboard
  - Redesign zoom controls as icon size controls
  - Context menu bugfixes
  - Add context menu item to show Properties in Other Locations
  - Improve support for context menus on touchscreens
  - Show extensions in templates names
  - Show sort menu options in list virw mode
  - Allow sorting in recent and search
  + Other enhancements:
  - Use better in-app notifications with AdwToast
  - Modernize "About" with AdwAboutWindow
  - Refine pathbar appearance
  - Label '/' with the OS name
  - Keyboard shortcuts overlay updates
  + Miscellaneous bugfixes:
  - Search engine bugfixes
  - Floating satus bar bugfixes
  - Fix popover crashes
  - Allow copying to a ramfs
  - Stop computing remote folders item count when disabled
  - Fix batch rename for files with the same name in search
    results
  - Don't trigger keyboard shortcuts ouside their intended scope
  + Maintenance work
  - Adapt to thumbnails API changes
  - Depend on libportal and drop wallpaper fallback setting
  - Modernize build with new meson features
  - Bump extensions library version
- Changes in BuildRequires following upstreams port to gtk4:
  + Drop pkgconfig(gnome-desktop-3.0), pkgconfig(gtk+-3.0) and
    pkgconfig(libhandy-1) and stop passing libportal=false to meson
    as it is now mandatory to support libportal.
  + Add pkgconfig(gnome-desktop-4), pkgconfig(gtk4),
    pkgconfig(libadwaita-1), pkgconfig(libportal) and
    pkgconfig(libportal-gtk4).
- Rename libnautilus-extension1 to libnautilus-extension2 and
  typelib-1_0-Nautilus-3_0 to typelib-1_0-Nautilus-4_0 following
  upstream soname bump.
* Mon May 30 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.2:
  + Close broken link message dialog on response.
  + Fix crash when opening new window from pathbar.
  + Fix remote filesystem check.
  + Updated translations.
* Mon Apr 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.1.1:
  + Revert wrongly introduced dependency on unstable gnome-desktop.
- Changes from version 42.1:
  + Add HighContrast syle support.
  + Preload dragged external file info in list view.
  + Override dark mode wallpaper when not using portal.
  + Avoid truncated popover in Compress dialog under X11.
  + Add checkerboard background to transparent thumbnails.
  + Style and scroll pathbar propperly in RTL languages.
  + Updated translations.
* Sun Mar 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.0:
  + Fix HiDPI thumbnails in list view.
  + Properly dispose pathbar to avoid crashes.
  + Updated translations.
* Sat Mar  5 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.rc:
  + Tweak thumbnail shadow drawing to fix performance regressions.
  + Various search engine fixes.
  + Updated translations.
* Sat Feb 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 42.beta:
  + Revert GTK 4 switch and intentional regressions.
  + Fix criticals when selecting non-ZIP formats for compression.
  + Add shadows to thumbnails in the old views.
  + Support dark mode setting.
  + Updated translations.
- Revert changes done in alpha, but leave the "gtk 4 port"
  BuildRequires in place, but disabled. Add back
  pkgconfig(gtk+-3.0), pkgconfig(libhandy-1) and
  pkgconfig(gnome-desktop-3.0). Rename back to
  typelib-1_0-Nautilus-3_0.
* Wed Jan 12 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 42.alpha:
  + Improve design of the file renaming UI.
  + Improve visuals of the file conflict UI.
  + Use GtkBuilder UI definitions for more components.
  + Fix "Move to"/"Copy to" from Starred.
  + Improve disposition of shell search provider.
  + Sort by subtype within type.
  + Allow searching by creation time.
  + Replace deprecated gexiv2 functions.
  + Fix extension API introspection annotations.
  + Expand on extension API documentation.
  + Add compressed archives to Recent files.
  + Preparations for GTK 4 switch.
  + Complete the GtkFlowBox-based grid view.
  + Remove EelCanvas-based grid view.
  * Improve design of the path bar.
  + Fix geographical coordinates displayed format.
  + Port to GTK 4.
  + Fix some GTK 4 switch regressions/warnings.
  + Updated translations.
- Update BuildRequires for switch to GTK4:
  + Replace pkgconfig(gtk+-3.0) with pkgconfig(gtk4)
  + Replace pkgconfig(libhandy-1) with pkgconfig(libadwaita-1)
  + Replace pkgconfig(gnome-desktop-3.0) with
    pkgconfig(gnome-desktop-4).
- Drop shared-mime-info BuildRequires: it's been a long time that
  the macros were not used anymore.
- Rename typelib-1_0-Nautilus-3_0 to typelib-1_0-Nautilus-4_0,
  following upstreams changes.
* Wed Jan 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.2:
  + Avoid cropping format popover in Compress dialog.
  + Fix "Move to"/"Copy to" from Starred.
  + Fix memory leak on tab switch.
  + Updated translations.
* Thu Nov 11 2021 Yifan Jiang <yfjiang@suse.com>
- Add BuildRequires python3-dataclasses since SLE 15 SP4 uses
  python36 to build.
* Fri Nov  5 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Add missing libnautilus-extension1 Requires to devel sub-package.
* Sat Oct 30 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.1:
  + Cache Scripts and New Document menus to avoid lags.
  + Ellipsize subtitle label in trash bar to reduce minimum width.
  + Fix build with meson 0.60.0.
  + Don't change action when unchecking in File Conflict dialog.
  + Fix progress reporting when skipping during extraction.
  + Offer skipping in case of extraction failure only when there
    are more files.
  + Remove leftover files after extraction failure.
  + Set keyboard focus on the row with the selected archive format.
  + Updated translations.
- Replace post(un) handling with new ldconfig_scriptlets macro.
- Drop pkgconfig(libportal) BuildRequires and pass libportal=false
  to meson, we are not building a flatpak.
- Pass tests=headless to meson, and add a check section and
  meson_test macro, run tests during build. Following this, add
  python3-gobject and tracker-miner-files BuildRequires needed for
  tests to run.
* Fri Sep 17 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.0:
  + Updated translations.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Sep  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.rc:
  + Disable background "Properties" while searching
  + Don't duplicate set wallpaper when not using portal
  + Updated translations.
* Mon Aug 23 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.beta:
  + Fix comma placement in the floating status bar.
  + Use standard::edit-name attribute where appropriate.
  + Bring "Open with..." options together in context menu.
  + Fix "Compress..." acting on file that was not the selected one.
  + Redesign "Compress..." dialog.
  + Provide creation of password-protected ZIP archives.
  + Fix search by date not working with Tracker engine'
  + Add link to Privacy Settings from Trash'
  + Indicate whether trash automatic emptying is enabled'
  + Updated translations.
* Fri Aug  6 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 41.alpha:
  + Replace deprecated gexiv2 symbols.
  + Make NautilusWindowSlot non-derivable.
  + Prevent closing popover when "Show Hidden Files" is toggled.
  + Hand preview updating over to FilesView.
  + Provide source .svg icon.
* Fri Jun  4 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.2:
  + Fix missing "Open Scripts Folder" menu item
  + Prevent reopening of previewer on window focus
  + Keep working directory when executing scripts
  + Updated translations.
* Wed May 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is nothing depending on the xxbit
  library anymore.
* Fri Apr 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.1:
  + Fix File conflict dialog crasheing on extensionless filenames.
  + Fix crashes when extracting encrypted archives.
  + Fix duplicated context menu entries for RAR archives.
  + Updated translations.
* Wed Apr 21 2021 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Update set_trusted.sh: Use the right value in gio command
  (bsc#1185026).
* Sat Mar 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Updated translations.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Group files depending on the opening app.
  + Fix crashes when closing the last tab.
  + Revert text-based clipboard workaround and use the dedicated
    type again.
  + Use GNOME 40 empty view styling.
* Mon Feb 15 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.beta:
  + Improve tab completion in the location entry.
  + Make manual rename more convenient in File conflict dialog.
  + Add support for extracting password-protected archives.
  + Implement new single-page design of Preferences dialog.
  + Use libhandy for window and headerbar.
  + Fix detection and handling of remote files.
  + Fix progress reporting in various cases.
  + Fix Batch rename dialog crashes.
  + Preserve mtime of non-empty directories on move.
  + Updated translations.
- New build requirement: pkgconfig(libhandy-1).
* Mon Jan 11 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Add support for creation date.
  + Fix several memory leaks.
  + Do not use default location instead of root in path bar.
  + Don't save window state when tiled.
- Add pkgconfig(libportal) BuildRequires: new dependency.
* Fri Nov 20 2020 bjorn.lie@gmail.com
- Update to version 3.38.2:
  + Search for tracker3 in PATH.
  + Fix batch rename dialog crashes.
  + Fix double-click row check.
  + Updated translations.
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.1:
  + Update starred URIs on move & rename.
  + Prevent recursion to speed up emptying trash.
  + Prevent stale items to be shown in starred view.
  + Revert icon emblem fixes in order to prevent performance
    issues.
* Tue Sep 29 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Fix missing Extract/Compress menu items.
  + Updated translations.
* Mon Sep 28 2020 dimstar@opensuse.org
- Update to version 3.37.92:
  + Port to Tracker 3.
  + Updated translations.
- Replace pkgconfig(tracker-sparql-2.0) BuildRequires with
  pkgconfig(tracker-sparql-3.0): port to Tracker 3.
- No longer limit the tracker-miner-files requires to version <
  2.99.
* Mon Sep 28 2020 dimstar@opensuse.org
- Update to version 3.37.91:
  + Fix batch renaming using metadata.
- Changes from version 3.37.90:
  + Port Properties dialog to GtkBuilder including various
    enhancements.
  + Prevent crashes when file operation is cancelled.
  + Auto-escape filenames on NTFS and exFAT mounts.
  + Preserve navigation history after opening Other Locations.
  + Use g_clear_signal_handler instead of custom codes.
- Changes from version 3.37.3:
  + Allow changing file owner under admin:/// scheme.
  + Update outdated appdata info.
- Changes from version 3.37.2:
  + Use tabular numbers for progress info.
  + Disable select-all while directory is loading.
  + Add newly created files to Recent.
  + Port to new PackageKit DBus API.
- Changes from version 3.37.1.1:
  + Add org.gnome.Nautilus.FileOperations2 interface.
  + Show notification on completion of file transfers if the window
    isn't focused.
  + Add support for zoom media keys.
  + Add dynamic tooltip for the toggle views button.
- Changes from version 3.37.1:
  + Always show pathbar background to fix styling glitches.
  + Add several missing shortcuts to the Keyboard Shortcuts dialog.
  + Unify pathbar and background context menus.
  + Refactor menu handling to fix repeated popover animations.
  + Mark Empty Trash and Delete All buttons as destructive actions.
  + Show infobar to allow installation of OSTree software.
  + Updated translations.
  Drop pkgconfig(x11) BuildRequires: no longer needed.
* Mon Sep 28 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Require tracker-miner-files 2.x; Tracker 3 is only supported in
  GNOME 3.38, but TW started the migration path.
* Fri May 29 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.3:
  + Fix broken tracker search engine under some locales.
  + Updated translations.
* Sat Apr 25 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.2:
  + Prevent jump to the old scrolling position after changing
    location.
  + Revert icon emblem fixes in order to prevent performance
    issues.
  + Fix content type detection when opening files from remote
    locations.
* Wed Apr 22 2020 Yifan Jiang <yfjiang@suse.com>
- Apply set_trusted.desktop and set_trusted.sh in spec to both SLE
  and Leap (jsc#SLE-11853).
* Mon Mar 30 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1.1:
  + Updated translations.
* Fri Mar 27 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Fix check to not clear clipboard after each move/copy
    operation.
  + Ignore hidden directories in the templates folder.
  + Honor umask when creating new files from templates.
  + Fix endless content size calculations in properties dialog.
* Fri Mar  6 2020 bjorn.lie@gmail.com
- Update to version 3.36.0:
  + Updated translations.
* Fri Feb 28 2020 bjorn.lie@gmail.com
- Update to version 3.35.92:
  + Fix crashes often happening when searching.
  + Say "Trash is Empty" only in the root of trash folder.
* Tue Feb 18 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.35.91.1:
  + Add support for hidden template files.
  + Fix conflict dialog for google-drive.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Fix crashes after conflict dialog response.
  + Add support for numeric keypad for zooming.
  + Fix missing filename results when searching.
  + Fix compilation on Wayland-only systems.
- Changes from SLE version 3.34.3 (bsc#1171506):
  + Fix crashes often happening when searching.
  + Fix crashes after conflict dialog response.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Nov 27 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Specify the correct pango version as a build dependency.
* Fri Nov 22 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.2:
  + Don't use hyphens when breaking filenames in multiple lines.
  + Fix drag and drop on scaled displays.
* Tue Nov 19 2019 Frederic Crozat <fcrozat@suse.com>
- Add explicit Conflicts in libnautilus-extensions1 to ensure
  smooth upgrade.
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.1:
  + Fix criticals and crashes when closing properties dialog.
  + Fix opening file previews in Sushi.
  + Fix criticals after trashing file.
- Drop nautilus-fix-criticals-move-file-trash.patch: Fixed
  upstream.
* Thu Sep 26 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add nautilus-fix-criticals-move-file-trash.patch: window: Fix
  criticals when moving file to trash.
* Tue Sep 10 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Fix emblems not appearing on files in some cases.
  + Respect recursivity setting in shell search provider.
  + Make recursive permission changes apply only to children.
* Mon Sep  2 2019 luke@ljones.dev
- Update to version 3.33.90:
  + Add tooltip to view menu button
  + Show warning in read-only directories when pasting files.
* Tue Aug  6 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.3:
  + Drop unintended string changes.
* Tue Aug  6 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Add padding to thumbnails in canvas view.
  + Use “Files” instead of “Nautilus” in appdata.
  + Add website link to about dialog.
  + Fix starring being allowed in XDG user directories, set to
    $HOME.
  + Fix starring in single indexed directories.
  + Fix starring in subdirectories of indexed directories.
  + Add missing menu mnemonics.
  + Remove extraneous menu separators.
  + Fix styling being incorrectly applied to GtkFileChooser
    instances.
  + Fix crashes when new tab position is set to “end”.
  + Allow whitespace at the beginning and end of path in location
    entry.
  + Fix leaky context menus.
  + Fix NAUTILUS_SCRIPT_SELECTED_FILE_PATHS not being set for
    scripts.
  + Fix critical warnings when window is closed while a
    notification is displayed.
* Tue May 21 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Require tracker-miner-files (boo#1135652).
* Sun May  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1 (CVE-2019-11461):
  + Fix Clang builds.
  + Fix crash when opening trash:/// from command line.
  + Fix CVE-2019-11461.
  + Correctly display file template labels in context menu when
    they contain underscores.
* Wed Mar 13 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Much smoother search, no more hang ups.
- Add pkgconfig(gstreamer-tag-1.0) BuildRequires: New depencency.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + New path bar design that improves discoverability of buttons.
  + Improve high contrast layout for accesibility.
  + New Nautilus icon.
  + Add coverage report.
  + Fix crashes.
  + Remove app menu.
  + Add issue triaging automation.
  + Make CI centralized.
  + Make starred files feature available on Tracker tracked
    directories.
  + Updated translations.
* Wed Dec 12 2018 bjorn.lie@gmail.com
- Update to version 3.30.5:
  + Fix a bunch of compiler warnings that could prevent building.
  + Fix location entry icon not reacting to clicks.
* Wed Nov 21 2018 bjorn.lie@gmail.com
- Update to version 3.30.4:
  + Fix crash when opening windows quickly.
  + Show trash action bar when trash status changes.
  + Implement rename file support in dbus for integration with
    desktop icons extension.
* Wed Oct 31 2018 bjorn.lie@gmail.com
- Update to version 3.30.3:
  + Fix crashes in search.
  + Fix crash in path bar usage.
  + Fix error dialog not showing when renaming.
  + Trigger location entry with the slash numpad key too.
* Fri Oct 12 2018 bjorn.lie@gmail.com
- Update to version 3.30.2:
  + Fix Google Drive files not opening.
  + Fix crashes when searching.
  + Fix triple click in pathbar to minimize the window.
  + Fix '/' and '~' not opening the location bar.
  + Fix header bar styling for 3rd party themes again.
  + Disable and warn about security risks when libseccomp and bwrap
    are disabled on unsupported cpus.
  + Fix various leaks.
* Wed Oct  3 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Improve high contrast styling.
  + Fix folders not expanding with arrow keys in list view.
  + Fix keyboard navigability when searching.
  + Fix crash on search.
  + Fix dark variant.
* Thu Sep 27 2018 xwang@suse.com
- Update set_trusted.desktop and set_trusted.sh: Move
  set_trusted.desktop file to /etc/skel/.config/autostart
  (bsc#1103523 bsc#1107854).
* Sun Sep 16 2018 badshah400@gmail.com
- Update to version 3.30.0:
  + No new changes.
- Changes from version 3.29.92:
  + Revert showing search filter popover on ctrl-f.
  + Add more tests.
  + Replace ambiguous slash with trash icon in path bar.
  + Fix path bar buttons not working with keyboard.
  + Fix crash when opening broken bookmarks from other locations.
  + Add warning about exceeded file name limit when renaming, etc.
  + Add plumbing for desktop extension (clipboard, undo/redo,
    etc.)
  + Tweak path bar styling.
* Mon Aug 27 2018 xwang@suse.com
- Add set_trusted.desktop and set_trusted.sh: If using /etc/skel
  function, the script can set files in $HOME/Desktop as trusted
  automatically when user login (bsc#1103523).
* Thu Jul 26 2018 bjorn.lie@gmail.com
- Update to version 3.29.90.1:
  + Flatpak improvements. Improved user facing experience and
    developer experience.
  + CI & CD set up. Increases stability, buildability and feedback
    cycle.
  + Distribute icons horizontally in the icon view.
  + Implement new pathbar/search design.
  + Implement new toolbar menus design.
  + Add background actions to the path bar.
  + Get background work ready for gtk4 port.
  + Add recent search engine.
  + Implement tests for Nautilus most critical operations.
  + Show Recency column in recent view.
  + Avoid recursivity in symbolic links.
  + Add a button in properties dialog to open GNOME Disks.
  + Add touch support for menus in views.
  + Fix error when accesing a file with x-nautilus-search.
  + Allow right clickin expanders.
  + Allow trashing/deleting Desktop dir.
  + Improve about dialog visuals.
  + Fix path bar changing size when navigating.
  + Fix MB/MiB confusion in preferences dialog.
  + Fix openning files failing from other applications in some
    cases due to DBus race.
  + Implement devel style to differentiate development builds.
  + Improve handling for impaired.
  + Fix wrong labels and file count in operations progress.
  + Remove special treatment for desktop files.
  + Remove special treatment for computer:///.
  + Fix triggering maximum file name when renaming.
  + Open search filters with popover open when using <ctrl>f.
  + Expose active windows for Ubuntu dash support.
  + Show "Open With" for files in trash.
  + Provide more information in prperties dialog for files in
    trash.
  + Implement showing properties of current view from path bar.
  + Avoid fuzzy icons in small sizes.
  + Warn if the renamed file will be hidden once renamed.
  + Improve and fix visuals in the new views.
  + Add show sidebar setting to the preferences dialog.
  + Remove experimental views UI setting in preferences dialog.
- Drop nautilus-icons.patch: Fixed upstream.
- Add pkgconfig(libseccomp) BuildRequires: New dependency.
* Tue Jul 17 2018 fstrba@suse.com
- Added patch: nautilus-icons.patch
  + Upstream fix for distribution of 512x512 icons instead of the
    16x16, 22x22, 24x24, 32x32 and 48x48 ones
* Mon Apr  9 2018 bjorn.lie@gmail.com
- Update to version 3.28.1:
  + Fix rename popover animation.
  + Allow deleting the desktop folder.
  + Fix gsettings in Flatpak install.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
- Drop gnome-patch-translation BuildRequires: There are no patches
  to be translated.
* Thu Mar 15 2018 bjorn.lie@gmail.com
- Update to version 3.28.0.1:
  + Don't show other apps starred files. Note for users: Starred
    files up to this point will be needed to be restarred.
* Tue Mar 13 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92.1:
  + Fix build failures.
* Mon Mar  5 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Don’t open files when double-clicking star icon.
  + Fix crashes caused by extremely long error messages.
  + Don’t strip extensions from folder names in “Compress…” dialog.
  + Set keyboard focus when programmatically selecting in list
    view.
  + Remove new folder name suggestion when there is an active
    selection.
  + Hide thumbnails when using small icons.
  + Reduce help overlay size.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Feb 14 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Enable closing tabs by middle-clicking.
  + Rename “favorite” files to “starred”.
  + Fix starring files with special characters.
  + Ellipsize tab labels less aggressively for large numbers of
    tabs.
  + Fix infinite loop when extracting encrypted archives.
  + Remove support for external bulk rename tools.
  + Only show option to star files in indexed locations.
  + Fix batch renaming for files with special characters in
    metadata.
  + Refactor extension library.
  + Show notification when unstarring files and allow undo.
  + Fix AppStream metadata being installed in a deprecated
    location.
* Tue Jan 30 2018 luc14n0@linuxmail.org
- Update to version 3.27.4:
  + Additions:
  - A close button for the path bar;
  - Microsoft Office types for search;
  - XF86Back and XF86Forward as key shortcuts;
  - Keyboard navigability to the new views;
  - DjVu as pdf type.
  + Improvements:
  - Touch support.
  - Flatpak support, now access to devices too.
  - Trash performance.
  - Window default position.
  - Starring files reliability.
  + Remove desktop icons.
  + Fix crashes when: detaching tabs and expanding folders.
  + Make wallpaper folder translatable.
  + Forbid more characters for FAT systems when renaming files.
- Drop enable-exif and enable-xmp meson options; and replace
  enable-gtk-doc meson option with 'docs', following upstream
  changes.
- Drop exempi-2.0, gthread-2.0, libexif, libnotify pkgconfig
  modules BuildRequires: they are no longer needed/used anymore.
- Add pkgconfig(gexiv2) BuildRequires following upstream change and
  replace libselinux-devel with its pkgconfig module counterpart,
  which is what meson really looks for.
* Wed Nov 22 2017 luc14n0@linuxmail.org
- Update to version 3.27.2:
  + Add starring files.
  + Fix:
  - Timestamps for files in the future.
  - Crash when expanding folders in list view.
  + Never soft folders before files in search.
  + Remove fts setting from preferences.
  + Reveal item when opened from the recent view.
- Update Url to https://wiki.gnome.org/Apps/Nautilus: current
  Nautilus' web page.
- Add: gio-2.0, gio-unix-2.0, gmodule-no-export-2.0 and gthread-2.0
  pkgconfig BuildRequires: note that they already were being pulled
  with glib-2.0 pkgconfig and used, since they live in the same
  devel package.
- Add x11 pkgconfig BuildRequires: it already was being used but
  wasn't declared.
- Drop %%glib2_gsettings_schema_requires macro: no longer needed
  since RPM file triggers.
- Replace intltool with gettext BuildRequires: upstream already did
  the migration and we don't want deviation to avoid unexpected
  bugs.
* Mon Nov 20 2017 mgorse@suse.com
- Update to version 3.26.2:
  + Fix crash in list view when expanding folders.
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 3.26.0:
  + Updated translations.
* Sat Sep  2 2017 zaitor@opensuse.org
- Update to version 3.25.92:
  + Fix desktop file parsing errors.
  + Bump GTK+ dependency version to 3.22.6.
  + Add mnemonic to replace button in file conflict dialog.
  + Show prefix matches first when searching.
  + Enable keyboard navigation in search type list.
  + Fix list view column picker not being centered in certain
    locales.
  + Make the path bar a drop target for files again.
  + Make sidebar visibility setting persistent.
  + Use spin button for thumbnailable file size limit setting.
  + Only allow directories to be dragged onto sidebar for
    bookmarking.
  + Make path bar clicks add new history entries.
  + Allow hiding unfocused search bar by pressing Escape.
  + Hide location entry after losing keyboard focus.
  + Allow deleting files with numpad delete key.
  + Forbid overwriting directories with files.
  + Updated translations.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Fix use of return key for conflict dialog.
  + Fix use of return key when searching not activating the
    selected file.
  + Add stable Flatpak builds.
  + Fix wrapping file names after a dot.
  + Use header bar for all dialogs.
  + Use portals for launching files in a sandbox with Flatpak.
  + Show error on empty name on batch rename dialog.
  + Change keyboard shortcuts for navigation of tabs similar to
    Firefox/Chrome etc.
  + Add a restore tab funcionality, similar to web browsers.
  + Fix rubberband with Wacom tablets.
  + Add Full Text Search (fts) to Nautilus so we search inside
    files content too.
  + Disable create link when clipboard is empty.
  + Disable zoom button if percentage is 100%%.
  + Bump Tracker dependency to version 2.0.
  + Make Tracker a hard dependency.
  + Assume Nautilus project is GPL3+.
  + Allow decompressing archives on remote locations.
  + Add license (LGPL2.1+)to Nautilus extensions.
  + Only use location in description for GNOME Shell search.
  + Add tablet pad controllers for common actions.
  + Fix <ctrl>+z when renaming a file not undoing the text.
  + Use upstream and newer fallback icons.
  + Provide mime type support for compressed archives, so Nautilus
    can be used for handling compressed archives outside of
    Nautilus too.
- Drop nautilus-tracker-2_0.patch: Fixed upstream.
- Relicense spec following upstream changes.
* Fri Jul 21 2017 zaitor@opensuse.org
- Add nautilus-tracker-2_0.patch: Fix build with tracker-2.0, patch
  from upstream git.
- Following above patch, replace pkgconfig(tracker-sparql-1.0) with
  pkgconfig(tracker-sparql-2.0) BuildRequires.
- Stop handling glib2_gsettings_schema_post(un),
  desktop_database_post(un), icon_theme_cache_post(un) and
  mime_database_post(un) in post(un), no longer needed as we have
  file-triggers to take care of this for us now.
* Tue Jul 18 2017 zaitor@opensuse.org
- Update to version 3.25.1:
  + Ported to Meson build system.
  + Fix replacing directory with symlink.
  + Avoid extraction of files if not enough space.
  + Fix not being able to drag the window from the path bar.
  + Add user preference for using the new views.
  + Fix DnD when using Google Drive.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Due to above change, no longer pass --disable-update-mimedb and
  - -enable-gtk-doc to configure, instead pass enable-exif=true,
  enable-gtk-doc=true and enable-xmp=true to meson macro. We want
  to build gtk-docs, exif and xmp support.
* Mon Jul 17 2017 zaitor@opensuse.org
- Update to version 3.23.2.1:
  + Release with autotools.
- Changes from version 3.24.2:
  + Hide desktop icons autostart in Ubuntu.
  + Confirm file name change in dialog conflicts with return.
  + Fix search activation not changing current directory.
  + Don't wrap names after . or _
  + Fix rubberband selection when using wacom tablets.
  + Fix crash in batch renaming.
* Sat Apr 29 2017 zaitor@opensuse.org
- Update to version 3.24.1:
  + Focus when a new folder is created.
  + Do not consider directory names with dots as extensions.
  + Fix move to/copy to when searching.
  + Various fixes to the new experimental views.
  + Fix scripts order in submenu.
  + Fix open in new tab/window in Other Places.
  + Show new networks available while in Other Places view.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Fri Mar 17 2017 zaitor@opensuse.org
- Update to version 3.23.92:
  + Fix count progress in operations when skipping files.
  + Improve meson build.
  + Selection and menus fixed for the experimental icon view.
  + Make Nautilus work with Flatpak and Builder.
* Sat Mar  4 2017 dimstar@opensuse.org
- Update to version 3.23.91:
  + Fix long-time, hard to reproduce, and common crash on desktop
    with "auto layout" icons.
  + Port building system to meson.
  + Make F2 toggle between selection modes, full file name or only
    file name withouth extension.
  + Recent files are now always files that only the user used,
    rather than any program/daemon like Dropbox updating the access
    time.
  + Fix Nautilus tests with extexnsions points.
  + Fix crash on desktop when refreshing.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 3.23.90:
  + Add <ctrl> Return as shortcut to open selected folder in new
    window.
  + <ctrl> N now opens the window in the same location as the
    current view.
  + Fixes on managing menus with keyboard.
  + Remove unused <ctrl> B shortcut.
  + Use a better empty state for trash.
  + Fix floating bar hide on hover when using tabs.
  + Syncronize gtk+ and Nautilus setting for sorting the folder
    first.
  + Select entire names for folder when renaming.
  + Support to open folders withouth permission using polkit and
    the admin backend.
  + Fix trash operations progress report.
  + Improve performance setting metadata only when necesary.
  + Fix progress reporting when copying.
  + Prevent toolbar menu dissapearing when "Hidden files" menu item
    is toggled.
  + Update app icon.
  + Fix icon scale computation when changing DPI.
  + Add <ctrl> M as alternate shortcut for renaming for those
    laptops withouth "f" keys.
  + Fix crash when pressing enter on search.
  + Fix failed build with tracker disabled.
  + Ask the user for using desktop files from unknown sources.
  + Improve the operations button animation in order to not need to
    show the operations popover.
  + Add an experimental icon view based on flow box with extra
    niceties under a gsetting preference.
* Sat Dec 10 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + Fix opening menus with keyboard.
  + Fix batch rename failing to rename in some cases.
  + Remove Bookmarks manager shortcut from the shortcut window.
  + Reverse view icon logic to match design expectations.
  + Make icons on desktop work on Wayland sessions.
  + Fix popover animations.
  + Use the same setting for "directories first" both for file
    chooser and Nautilus.
  + Select entire names when renaming a folder.
  + Fix wrong progress information in operations due to races.
  + Fix wrong progress information in operations in non local
    files.
  + Fix regresion on speed when copying or moving files.
* Fri Oct 14 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Multiple batch renaming fixes.
  + Multiple compression integration fixes.
  + Fix not showing "eject" and other options for devices in the
    context menu in the desktop.
  + Rework clipboard handling, fixing desktop<->Nautilus
    interaction.
  + Fix overlaping icons on desktop in some cases, noticeabily in
    Ubuntu.
  + Fix wrong progress information in operations when skipping
    files.
  + Fix gnome-shell search only searching for whole words.
  + Show location as default for list view on Recent.
  + Fix context menu position in Wayland or other non-global
    coordinates systems.
  + Update man page of nautilus.
  + Add revealer for warnings in batch rename dialog.
  + Add tooltips to batch rename dialog file names.
  + Port nautilus classes to G_DECLARE.
  + Extend Nautilus File API for regular files.
  + Don't crash for simple leaks on the views.
  + Updated translations.
- Drop nautilus-enable-eject-option-on-selection-menu.patch and
  nautilus-fix-desktop-icon-smash.patch: Fixed upstream.
* Sun Oct  9 2016 qzhao@suse.com
- Update nautilus-fix-desktop-icon-smash.patch:
  porting upstream's solution to work out the general aspect
  (bsc#979072, bgo#765601).
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Increase gtk+ depencency version.
  + Updated translations.
* Wed Sep 14 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Fix libgd warning.
  + Numerous batch renaming improvements and fixes.
  + Detect .bz and .xz as extensions for renaming.
  + Fix operations popover too small.
  + Add dummy --no-desktop option so Dropbox plugin works again.
  + Fix build when using the --disable-tracker compile time option.
  + Updated translations.
- Run spec-clean: Updates macros to current standard and adds
  pkgconfig BuildRequires, also removes obsolete clean section.
- Conditionally BuildRequire and apply gnome-patch-translate and
  translations-update-upstream for non-openSUSE only.
- Drop nautilus2-devel Obsoletes/Provides: We do not support
  upgrading from any version where this would apply.
* Fri Sep  2 2016 zaitor@opensuse.org
- Update to version 3.21.91.1:
  + mime-actions: Fix shift+control+down segfault on a folder.
  + Use templates for glib-mkenums.
  + Fix compiler warning.
  + batch-rename-utilities:
  - Protect against null error.
  - Print warnings if query goes wrong.
  + file-undo-operations: Add plural support for strings.
  + batch-rename-dialog: Add plural support for strings.
  + Updated translations.
- Drop nautilus-fix-compiler-warning.patch: Fixed upstream.
* Wed Aug 31 2016 dimstar@opensuse.org
- Update to version 3.21.91:
  + Implement batch renaming tool.
  + Implement compressed files support.
  + Rework the view menus.
  + Separate desktop handling from Nautilus.
  + Add missing cut shortcut.
  + Add <ctrl>= as "zoom in" shortcut.
- Add pkgconfig(gnome-autoar-0) BuildRequires: new dependency.
- Rebase nautilus-enable-eject-option-on-selection-menu.patch and
  nautilus-fix-desktop-icon-smash.patch.
- Add nautilus-fix-compiler-warning.patch: Fix function potentially
  reching the end without returning a value.
* Tue Aug 30 2016 dimstar@opensuse.org
- Update to version 3.20.3:
  + Support HDPI in desktop margins.
  + Fix opaque desktop background after changing themes.
  + Fix gnome-shell search not providing results or making the CPU
    at 100%% even if closed.
- Drop nautilus-desktop-canvas-view-scale-desktop-workarea.patch:
  fixed upstream.
* Tue Aug  2 2016 zaitor@opensuse.org
- Add nautilus-desktop-canvas-view-scale-desktop-workarea.patch:
  The problem is that in the function canvas_container_set_workarea
  the screen width and height are in "application pixels" while the
  workarea ones are in "device pixels" so when the scaling is > 1,
  the margins are not properly setted (bgo#769302).
* Tue Aug  2 2016 qzhao@suse.com
- Add nautilus-fix-desktop-icon-smash.patch: Fix desktop icons
  smashed together at the fist start time (bsc#979072, bgo#765601).
* Fri Jul 29 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Fix white desktop background after changing themes.
  + Improve double click detection.
  + Fix path bar menu on wayland appearing on random places.
  + Only save zoom level if the level has changed.
  + Fix date difference calculation for attributes like Modified
    Date.
  + Hide floating bar on hover.
  + Fix detection of remote systems for not thumbnailing.
  + Fix sorting on Japanese locale.
  + Fix gnome shell search provider not being recursive.
  + Fix copy operation lags.
  + Avoid unresponsiveness when file chooser is opened.
  + Fix renaming duplicated logic on search and recent.
  + Fix trash handling to delete files if disk is full.
- Drop nautilus-adjust-style-priority.patch and
  nautilus-bsc979947.patch: Fixed upstream.
* Fri Jul 15 2016 tyang@suse.com
- Add nautilus-enable-eject-option-on-selection-menu.patch
  Enable eject option on selection menu (bsc#981950, bgo#768355).
* Mon Jun 20 2016 mgorse@suse.com
- Add nautilus-bsc979947.patch: only write zoom level to user
  config if the user has adjusted it (bsc#979947).
* Tue Jun 14 2016 zaitor@opensuse.org
- Rebase nautilus-adjust-style-priority.patch to what upstream
  committed (boo#982134).
* Fri Jun  3 2016 qzhao@suse.com
- Add nautilus-adjust-style-priority.patch: Fix white desktop after
  changing themes: The behavior of two style providers with the
  same priority is undefined and gtk happens to prefer the provider
  that got added last. Use a higher priority here to avoid this
  problem (bsc#982633, bgo#765687).
* Thu May 19 2016 tyang@suse.com
- Update to GNOME 3.20.2 Fate#318572
* Thu Apr 28 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Fix crash if using scripts.
  + Fix shortcuts to change views mode.
  + Do not switch focus to created tabs.
  + Fix margins on sidebar context popover.
  + Fix the empty states icons blocking clicks for activating
    context menus.
  + Show same name in the path bar as in other locations when using
    mounts.
  + Make more dialogs modal.
  + Allow "move to" action in network locations.
  + Fix crash when searching and closing with multiple windows.
  + Fix path bar not updating to the new location when finalizing
    search.
  + Show an error dialog on falied connection to servers in the
    other locations view.
  + Fix odd empty operations popover.
  + Fix hamburguer menu action not being available when closing a
    tab.
  + Select first item in the views only when searching.
  + Fix crash when creating a new window of nautilus from the shell
    when the application was not running.
  + Allow more applications to be set as default in network
    locations.
  + Make renamed or created files scroll the view to the position
    of the files.
  + Updated translations.
* Thu Apr 14 2016 tyang@suse.com
- Update to GNOME 3.20 Fate#318572
- Drop patches:
  + 0001-application-add-force-desktop-action.patch
  + 0001-dnd-fix-dnd-issues-with-Type-Link-desktop-files.patch
  + 0001-NautilusPropertyDialog-Fix-user-list-for-owner-chang.patch
  + 0001-window-sync-initial-state-for-start-with-sidebar-act.patch
  + nautilus-bgo711115-format-item-for-volumes-disappeared.patch
  + nautilus-bgo711583-crash-modify-link-hash-table.patch
  + nautilus-bgo722616-check-for-valid-location-entry-widget.patch
  + nautilus-bnc872820-gtkheaderbar.patch
  + nautilus-desktop-icon-name.patch
  + nautilus-rename-background.patch
  + nautilus-drives-and-volumes-on-desktop.diff
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Improve path bar sliders sizing, making them less prominent.
* Fri Mar 18 2016 dimstar@opensuse.org
- Update to version 3.19.93:
  + Use better arrows for the path bar.
- Changes from version 3.19.92:
  + Use better thread handling in undo operations.
  + Disable zoom and sort menus when the folder is empty.
  + Always show the sliders in the pathbar to avoid pathbar
    clipping.
  + Disable Alt+Home for desktop window, avoiding to change the
    desktop location.
  + Avoid drag and drop visual hint in list view.
  + Make sure we select the previous folder when going upwards in
    the hierarchy.
* Fri Mar 11 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Use GTask instead of the old gioscheduler.
  + Improve wording of the conflict dialog.
  + Make dialogs transients and modals for parent windows.
  + Reveal folder on creation.
  + Fix dark theme background.
  + Hide hidden files when renamed from normal files.
  + Select first file while searching even if search didn't
    finished.
  + Multiple localization fixes.
  + Fix the shell search provider.
  + Style fixes with latest gtk+.
  + Hide undo delete notification if the user undo.
  + Don't show thumbnails for small zoom level.
  + Fix the info bar when navigating a DVD or a loopback mounted
    device.
  + Allow copying from the trash.
  + Remove notifications when the application closes, fixing the
    "notifications appear after reboot".
  + Add Open With Other Application for all items, allowing i.e.
    desktop files to be opened with a text editor.
  + Add <alt>+<return> shortcut for properties, matching other
    GNOME applications.
  + Remove the "Untitled" when creating templates.
  + Updated translations.
* Thu Feb 25 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Reorganize shortcuts.
  + Remove bookmark manager.
  + More robust search.
  + Add preference for menu item "Delete Permanently".
  + Add preference for menu item "Create Link".
  + Fix jp2 images crashing nautilus.
  + Change icon of operations cancelation when operation is
    finished.
  + Allow Nautilus windows to be styled differently than other
    applications.
  + Add new search popover and search filtering.
  + Allow different search preferences for remote and local
    separately.
  + Remove sorting preference, since the view menu is the
    preference itself.
  + Allow different view type setting for search and normal.
  + Rework preferences window.
  + Add another zoom level and improve icons padding.
  + Allow to open the "Other Locations" in new tabs or windows.
  + Make operations popover keyboard navigable.
  + Limit search to maximum 5 years.
* Fri Jan 29 2016 mgorse@suse.com
- Add
  0001-NautilusPropertyDialog-Fix-user-list-for-owner-chang.patch:
  fix handling of the user list (bsc#963724).
* Wed Jan 27 2016 damjanovic.ivo@gmail.com
- Update to version 3.19.2:
  + Show free space in Other Places.
  + Add shortcuts window.
  + Fix new window Gnome Shell dash item.
  + Add kudos data for Gnome Software.
  + Check availability of PackageKit for installing extra apps.
* Mon Jan 25 2016 zaitor@opensuse.org
- Update to version 3.18.5:
  + Fix recurrent crashers on search.
  + Fix loading hint while searching.
  + Fix search on history.
  + Avid crash with big images when thumbnailing.
  + Fix XGD_CURRENT_DESKTOP for multiple desktops.
* Fri Dec 18 2015 zaitor@opensuse.org
- Update to version 3.18.4:
  + Fix crash on copying directory.
* Tue Dec 15 2015 zaitor@opensuse.org
- Update to version 3.18.3:
  + Check availability of PackageKit for installing extra apps.
  + Fix overflow in 32 bits systems.
  + Fix renaming popover misplaced in the desktop.
  + Fix blank square in the view after changing view modes or
    locations.
  + Fix crash when clicking preferences.
  + Widespread work on removing leaks, that usually causes crashes.
  + Operations start visibility improved, showing the popover.
  + Fix wrong date calculation.
  + Fix another issue with nautilus opening location in the wrong
    window.
  + Fix "move to" action.
* Fri Nov 13 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Show SD cards and external hard drives in the sidebar, not in
    the Other Places view.
  + Fix nautilus not opening a new window when used from command
    line.
  + Fix crash using samba.
  + Allow 3rd party themes to tweak operations button color.
  + Fix recurrent crash when closing Nautilus.
  + Avoid empty operations popover.
  + Fix nautilus opening locations in a different window than the
    one the user is using.
  + Fix Other Places lock ups.
  + Adapt rename entry to the width of the file and increase the
    minimum.
  + Increase max width of operations popover to fix ellipsize
    translations.
  + Fix recurrent crashers.
  + Updated translations.
* Thu Oct 15 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Multiple crash fixes.
  + Use GtkPlacesSidebar hints to improve drag and drop experience.
  + Fix remote filesystem check for google drive.
  + Fix properties not being available on some file systems.
  + Fix not being able to trash on some file systems.
  + Fix calculation of operations button that was not showing soon
    enough in big operations.
  + Get filesystem type asynchronously, so the view is never
    frozen.
  + Make the delete shortcut also work for delete permanently on
    filesystem that does not support trash.
  + Updated translations.
* Wed Sep 23 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Fixed various sidebar crashes.
  + Use a correct file number for copy/move operations.
  + Fix various operations crashes.
  + Google Drive support.
  + Fix desktop icons not appearing for the first time.
  + Fix searching on recursive mode but not working properly.
  + Fix remote warning label not showing sometimes.
  + Use better file renaming positioning when using keyboard
    shortcut.
  + Fix a crash on Other Locations.
  + Updated translations.
* Fri Sep  4 2015 zaitor@opensuse.org
- Update to version 3.17.91:
  + Ground work for code isolation and clean up of views.
  + Don't add more items on the filechooser sidebar.
  + Adjust animation for progress button.
  + Track and fix all translation issues.
  + Improvements and fixes in the new "Other Locations" view.
  + Disable sorting on Recent and Search and ensure criterion
    correcteness.
  + Add a preference and disable by default automatic opening of
    folders while hovering on drag an drop operations.
  + Don't search recursively on remote locations, and provide
    feedback when that happens.
  + Fix major crashers and races.
* Fri Aug 21 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Don't show sort menu on search.
  + Use watch cursor with pointer.
  + Use popover for renaming.
  + Improve operations button feedback.
  + Code isolation of the model and view of nautilus.
  + Add a new "other places" view for networks and internal
    partitions.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Ignore no desktop if not first launch.
  + Make the toolbar menu settings the only and permanent settings.
  + Use Modified Time for all locations except Recent.
  + Implement new design for operations feedback.
  + Hide sort menu on Recent.
  + Switch to list view if searching.
  + Provide smarter location displayed names.
  + Show feedback when there is no search results.
  + Fix floating bar loading feedback.
  + Add feedback when the current shown folder is empty.
  + Updated translations.
* Sat May 30 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Fix window focus issues when starting nautilus.
  + Fix handling of command line options in diferent cases.
  + Decrease the padding on list view.
  + Use a dialog for creating folders.
  + Use a dialog for renaming files.
  + Allow F5 and ctrl+r as shortcuts for refresh the view.
  + Make the zoom slider the preference itself.
  + Allow opening with a different app than default for multiple
    files.
  + Fix view scrolling when selecting with ctrl + mouse.
  + Don't always make the sidebar visible on start.
  + Allow opening folders with another app.
  + Show Delete Permanently on systems that does not support Trash.
  + Add Alt<down> shorcut for opening.
  + Fix some icons sizes inconsistency.
  + Add public API documentation for Nautilus extensions.
  + Add a gsetting to toggle recursive search.
* Wed May 13 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Allow opening multiple files with a different app than default.
  + Fix sidebar always visible on starting nautilus even with
    setting disabled.
  + Allow folders to be opened with a different app than default.
  + Allow F5 and ctrl+r as shortcuts for reload the view.
* Wed Apr 15 2015 zaitor@opensuse.org
- Update to version 3.16.1:
  + Fix xf86-favorites shortcut.
  + Decrease padding on list view.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Support multiple desktop names in XDG_CURRENT_DESKTOP.
  + Workaround distcheck.
* Wed Mar 18 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Fix double-clicking on password-protected webdav share, not
    showing the password dialog.
  + Don't create desktop on protocols diferents than X11.
* Thu Mar 12 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Dimmed labels for list columns.
  + Fix new folder shortcut.
  + Fix delete shortcut in the trash.
  + Don't use libgd notifications and implement them with Gtk+.
  + Don't show notifications in desktop.
  + Esc shortcut for exiting search mode.
  + Fix translation problems with notifications.
  + Fix cluttered desktop icons due to the icon size changes.
  + Make toolbar buttons accesible for A11y.
  + Fix open with another app for multiple selection.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Bug fixes and clean ups for the GAction port.
  + Add path as description of the Gnome shell provider.
  + Add in app notification when deleting items.
  + Set move to trash shortcut to just the Delete key.
  + Avoid hiding the search on small windows.
  + Improve file operations dialogs UI.
  + Show a warning dialog when the user uses the old move to trash
    shortcut.
  + Improve list view columns.
  + Add a new modified column with the time.
* Mon Jan 26 2015 badshah400@gmail.com
- Update to version 3.15.4:
  + Port to GAction.
  + Rework menus and zoom levels.
  + Use monospace font for permissions column.
  + Port to GNotification.
  + Stop loading custom accel maps file.
  + Use inline toolbar for column chooser dialog.
  + Fix new window activation with desktop icons enabled.
  + Fix regression with --new-window option.
  + Use mount name if available for file operations progress
    report.
  + Set max-width for value labels in properties.
  + Increase default window width.
* Fri Jan  9 2015 tyang@suse.com
- Added 0001-dnd-fix-dnd-issues-with-Type-Link-desktop-files.patch:
  Fix upstream bug https://bugzilla.gnome.org/show_bug.cgi?id=720390
  and bnc#896702 about Type-link-desktop-file issue.
* Tue Nov 25 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Fix new window activation with desktop icons enabled.
  + Updated translations.
- Drop nautilus-as-desktop-launch.patch: Fixed upstream, workaround
  in our patch no longer needed.
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.1:
  + Fix regression with --new-window option.
  + Use mount name if available for file operations progress
    report.
  + Set max-width for value labels in properties.
  + Increase default window width.
* Thu Nov  6 2014 dimstar@opensuse.org
- Add nautilus-as-desktop-launch.patch: Start nautilus
  - -gapplication-service during autostart (boo#900728).
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Tue Sep 16 2014 dimstar@opensuse.org
- Update to version 3.13.92:
  + Improve toolbar and pathbar styling with GTK 3.14.
  + Expand properties dialog notebook in its parent container.
  + Fix crash when using the rename field context menu in list
    view.
  + Fix crash when using a screen reader in canvas view.
  + Fix crash when changing icon captions setting.
* Thu Sep 11 2014 tyang@suse.com
- Remove the nautilus-crash-sftp-bookmark.patch:
  Fix the bug about USB issue (bsc#892725).
* Wed Sep  3 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Performance improvements for canvas and list views.
  + Remove duplicate actions in gear menu when app menu is not in
    use.
  + Fix CSS style for new GTK.
  + Fix handling of sort-directories-first setting.
* Thu Aug 21 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Fix problems with fast group/owner changes.
  + Fix user list for owner changes.
  + Use margin-start/end instead of deprecated margin-left/right.
  + Fix floating bar CSS style after Adwaita GTK move.
  + Fix build glitch with enums file.
  + Updated translations.
* Fri Aug 15 2014 federico@suse.com
- Added nautilus-bnc872820-gtkheaderbar.patch for bnc#872820.  This is
  a backport of the code to make Nautilus use a standard GtkHeaderBar
  instead of its own custom code for a toolbar/titlebar.
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Fix a missing unref.
  + Fix a crash in selection handling.
  + Use header bar for properties dialogUse header bar for
    properties dialog.
  + Use new gear menu icon.
  + Include application-specific theming for Adwaita.
  + Share pathbar styling with GTK+.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Drop gnome-icon-theme BuildRequires and Requires: the icon theme
  has been renamed to adwaita-icon-theme and is a mandatory
  component of GTK+ 3.13.x.
* Thu Jun 26 2014 tyang@suse.com
- Add nautilus-crash-sftp-bookmark.patch:
  Fix the bug about sftp bookmark crash issue (bsc#873210).
* Wed May 28 2014 tyang@suse.com
- Add nautilus-desktop-icon-name.patch:
  Fix upstream bug https://bugzilla.gnome.org/show_bug.cgi?id=659520
  desktop icon name translation issue (bsc#870384).
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Port to be a DBusActivatable application.
  + Fix a crash when switching back from the trash folder.
  + Do not use legacy emblem names.
  + Sync the GTK+ setting for sort-directories-first.
  + Fix crash when enumerating windows.
  + Use spaces between em dashes in file operations.
  + Use headerbar in bookmarks window.
  + Fix arrow in connect server dialog for RTL languages.
- Rename .desktop file following upstream changes.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Don't resolve symlinks before launching an application.
  + Fix a crasher when switching location out of trash.
  + Fix a crasher when enumerating windows.
  + Fix a crasher when listing bookmarks.
  + Use headerbar in bookmarks dialog.
  + Fix arrow direction in connect server dialog for RTL.
  + Use spaces between em dashes in file operations.
  + Do not use legacy emblem names.
  + Sync the GTK+ setting for 'sort-directories-first'.
* Fri Mar 28 2014 mgorse@suse.com
- Add nautilus-bgo711115-format-item-for-volumes-disappeared.patch,
  0001-window-sync-initial-state-for-start-with-sidebar-act.patch,
  nautilus-bgo711583-crash-modify-link-hash-table.patch,
  nautilus-bgo722616-check-for-valid-location-entry-widget.patch,
  nautilus-rename-background.patch: various bug fixes from
  upstream gnome-3-10 branch.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Only show one button for mixed Video CD/Video DVD media.
  + Add a force-desktop action to NautilusApplication.
* Tue Mar 18 2014 fcrozat@suse.com
- Add 0001-application-add-force-desktop-action.patch: ensure
  - -force-desktop always works [bnc#867309, bgo#726114]
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Port to GtkHeaderBar.
  + Fix tab label not being update on removals or renames.
  + Fix minimum size requisition of Nautilus windows.
  + Fix remote mounts not being detected as removed.
  + Fix high CPU usage when searching with criteria.
  + Fix unwanted search entries on the desktop.
  + Fix initial value of start-with-sidebar.
  + Fix some critical assertions.
  + Fix a crash when selecting an unsupported custom image.
  + Remove Set as Background action on interactive DND.
  + Use unity-control-center when under Unity.
  + Add film strip in nautilus rather than in totem.
- Replace pkgconfig(tracker-sparql-0.18) for
  pkgconfig(tracker-sparql-1.0) BuildRequires.
- Drop COPYING-DOCS from %%docs, no longer present.
* Wed Dec 18 2013 zaitor@opensuse.org
- Update to version 3.11.3:
  + Don't perform deep counts on regular files.
  + Fix overlapping filenames on hover in canvas view.
  + Fix crasher when changing the symlinks cache.
  + Standardize Help/About/Quit for the app menu.
  + Remove Enter Location from the app menu.
  + Use search bar style for the query editor.
  + Support building against Tracker 0.18.
- Stop injecting tracker 0.18 support before build.
* Thu Dec 12 2013 dimstar@opensuse.org
- Drop nautilus-drives-and-volumes-on-desktop.diff: this patch has
  been disabled at least since openSUSE 11.1, which was 5 years
  ago.
* Sat Nov 23 2013 dimstar@opensuse.org
- Replace pkgconfig(tracker-sparql-0.16) BuildRequires with
  pkgconfig(tracker-sparql-0.18): move to Tracker 0.18.
- Replace tracker-spaqrl-0.16 in configure with
  tracker-sparql-0.18, using sed.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Bring back eject button in sidebar.
  + Fix rename entry rendering.
  + Avoid a crash if inhibit fails.
  + Center tab labels.
  + Fix DND move.
  + Updated translations.
* Wed Nov  6 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Fix rename entry position with Gtk 3.10.
  + Fix default DnD operation to move on same fs.
  + Fix crash on file copy.
  + Updated translations.
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Make search provider return results again.
  + Updated translations.
* Tue Sep 17 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Use new gtk_drag_begin_full API.
  + Increase default window width to fit four icons.
  + Don't filter out NoDisplay applications from "Open With...".
  + Fix desktop file categories.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + Use a GtkRevealer for the search bar.
  + Don't present redundant options for operations on single files.
  + Fix desktop window for newer GTK+ client side decorations.
  + Fix double menu when right clicking on the pathbar.
  + Fix headerbar appearance with latest GTK+.
  + Fix copy/cut/paste accels not working correctly.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Fix support for HiDpi displays.
  + Replace control characters when fixing filenames for FAT.
  + Fix crash while dragging an expander in list view.
  + Don't use deprecated GtkStock and GtkImageMenuItem.
  + Fix "Reset to Defaults" not resetting columns in List view.
  + Use more friendly strings in the Location column in List view.
  + Add Access Date column in Recent.
  + Add Location column by default in search views.
  + Fix search not remembering per-view settings.
  + Use new GTK titlebar look.
  + Fix hidden files setting not correctly refreshing on change.
  + Fix incorrect click target in canvas view under certain
    circumstances.
  + Fix DnD glitches on pathbar buttons.
  + Show invalid filename dialog when copying, if required.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Shade rubberbands on the desktop using the wallpaper color.
  + Port to GtkPlacesSidebar.
  + Check for available mail clients before enabling sendto
    extension.
  + Enter location bar upon entering "~".
  + Add a menu item to open parent folder of search/recent items.
  + Use Shift+Ctrl+Z, not Ctrl+Y, for Redo.
  + Remove multicontext menu items from editable entries.
- Changes from version 3.8.2:
  + Don't grab focus to search entry needlessly.
  + Increase default size to fit 4 columns of icons.
  + Remove no-longer-existing keys from GConf conversion.
  + Change 'x-nautilus-search:' To 'Search' in tooltips.
  + Updated tranlsations.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Use a consistent name for applications in the Open With context
    menu.
  + Don't follow symbolic links when searching recursively.
  + Increase default sidebar width.
  + Fix resetting view to default preferences not working.
  + Fix behavior of search entry with external Input Methods.
  + Fix partial ranking order of search results.
  + Fix move of special icons on the Desktop triggering file
    operations.
  + Fix copy action not working in Recent.
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires, so it can
  be versioned.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Fix inconsistency in handling of NoDisplay=true applications.
  + Updated translations.
* Wed Mar 20 2013 zaitor@opensuse.org
- Update to version 3.7.92:
  + Ensure target directories exist when restoring trash contents.
  + Export non-VFS URIs to DnD selections.
  + Hide Change Background desktop action if g-c-c is not
    installed.
  + Fix double tap not working on certain touchscreen devices.
  + Fix for removal of org.gnome.desktop.background draw-background
    setting.
  + Fix inability to move desktop icons to non-primary displays in
    certain configurations.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + Export an OpenLocations property over DBus.
  + Add a way to reuse and raise existing windows already opened to
    a given location.
  + Use an ARGB window for the desktop.
  + Stop drawing the desktop background.
  + Register our GtkApplication with gnome-session.
  + Fix Tracker search not working correctly.
  + Fix activation of search provider results.
  + Fix nautilus --quit from terminal not working.
* Mon Feb 18 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + Add back a Treeview option for list view. This is off by
    default, and is backed by a checkbox in the Preferences dialog.
  + Add a "Connect to Server" item in the Network section of the
    sidebar.
  + Add a "Format..." item in volume context menus in the sidebar.
  + Fix accelerators not showing up in gear and view menus.
  + Use G_APP_INFO_CREATE_NEEDS_TERMINAL instead of handrolled
    code.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Switch to hovered locations on DnD.
  + Support a --force-desktop commandline option for classic mode.
  + Add a separate desktop file for classic mode integration.
  + Use a better position for navigation button popup menus.
  + Fix many memory leaks.
  + Fix a crasher when a file in trash has reserved characters in
    the filename.
  + Fix a crasher when closing the sidebar immediately after
    construction.
  + Fix a crasher closing the properties dialog while calculating
    folder size.
  + Fix backup files showing up in search provider results.
  + Fix floating bar buttons being added twice.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Support a --select commandline option to force selection of the
    passed-in URI.
  + Add source hints to notifications.
  + Modernize build infrastructure.
  + Use public GTK-a11y support instead of our own hacks.
  + Fix a crasher in the Shell search provider.
- Replace pkgconfig(tracker-sparql-0.14) BuildRequires with
  pkgconfig(tracker-sparql-0.16), following upstream.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Update search provider to org.gnome.Shell.SearchProvider2
    interface.
  + Rely on GIO to parse ".hidden" files.
  + Consistently use unicode ellipsis instead of three periods.
  + Use a different label for removing a file from "Recent".
  + Restore the previous behavior wrt. framing for custom icons.
  + Share the "show hidden" GSetting option with the GTK+
    file chooser.
  + Fix missing unmount sync notification under some circumstances.
  + Fix infinite loop while deep counting the size of "/".
  + Fix wrong filename when restoring file from trash.
- Drop nautilus-make-sure-to-always-notify-when-unmounting.patch:
  fixed upstream.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Request to render larger thumbnails by default.
  + Don't quote the current location name in search bar.
  + Use "Run" in menus when launchine executables.
  + Fix stray Empty Document item in New Document menu.
- Drop nautilus-stray-empty-document.patch: fixed upstream.
* Thu Feb 14 2013 dimstar@opensuse.org
- Update to version 3.7.1:
  + Turn on again recursive search for the simple engine.
  + Enable incremental loading for search directories.
  + Add extra information to image properties page.
  + Show free space pie chart for the local root filesystem.
  + Resolve symbolic links before launching a file.
  + Avoid sync I/O when reading bookmark locations.
  + Don't add non-existent XDG folders to the sidebar.
  + Don't offer to remove built-in XDG folder bookmarks.
  + Fix black input field when renaming a file in icon view with
    XIM enabled.
  + Fix wrong return location when unmounting a remote mount.
  + Fix notebook tabs not properly switching after timeout when
    hovered.
  + Fix search toggle button state inconsistent when switching
    between tabs.
  + Fix crasher when using the Tracker engine from the Shell search
    provider.
  + Fix crasher in Shell search provider.
  + Fix crasher when unmounting a volume under certain.
    circumstances.
* Thu Feb 14 2013 mike.catanzaro@gmail.com
- Add nautilus-stray-empty-document.patch, don't show a extra Empty
  Document entry. (bnc#803649, bgo#687139)
* Thu Dec 20 2012 zaitor@opensuse.org
- Add nautilus-make-sure-to-always-notify-when-unmounting.patch,
  fixes missing notification when unmounting drives (rh#885133).
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.3:
  + Fix symbolic links on remote volumes not activating default
    action.
  + Fix duplicated query editor filter rows when changing search
    location.
  + Fix search toolbar disappearing with very long folder names.
  + Fix missing Trash action after "Recent" was visited.
  + Fix missing frame around thumbnails for some zoom factors.
  + Fix crash when unmounting remote volumes.
* Tue Oct 30 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Open default location for remote shares when mounting.
  + Resolve symbolic links before launching a file.
  + Fix missing search results from Tracker for names that contain
    hyphens.
  + Fix black input field when renaming a file in icon view with
    XIM enabled.
  + Fix missing item selection in the sidebar when starting up.
  + Fix wrong return location when unmounting local and remote
    mounts.
  + Fix search tabs changing location to $HOME on tab switch.
  + Fix search toggle button state inconsistent when switching
    between tabs.
  + Fix search string being eaten by a hidden entry under certain
    circumstances.
  + Fix missing tooltips on stock toolbar buttons.
  + Fix crasher when using the Tracker engine from the Shell search
    provider.
  + Fix crasher in Shell search provider.
  + Fix crasher when unmounting a volume under certain
    circumstances.
* Mon Oct 15 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Fix floating bar not disappearing on search finish
  + Fix fullcolor icons appearing in the pathbar for mount roots
  + Fix drag and drop of multiple rows in list view
  + Fix search relevance not being applied correctly when searching
  + Fix sidebar visibility switch applying to all windows
  + Fix search location when moving to a search directory in
    Back/Forward history
  + Fix missing search results with non-ASCII characters
  + Fix Home/Trash not showing up in shell provider results
  + Fix startup notification not working when opening multiple
    windows
  + Fix search results not focusing when activated from the Shell
  + Fix error dialog not showing up when entering a non-existant
    location in Connect to Server
  + Fix inability to open files after cancelling a rename in list
    view under some circumstances
  + Fix desktop icons not following the primary monitor workarea
    when multihead is used with the desktop enabled
  + Fix crasher when search string changes too fast
  + Fix crasher when enabling search while loading a directory
  + Fix crasher when trying to open a saved search file
  + Fix crasher when Tracker is installed but not running
  + Fix crasher in the shell search provider for bookmarks/mounts
    with an empty name.
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Fix toggling of hidden files visibility in searches
  + Fix base directory appearing in search results
  + Fix missing search results under some locales
  + Fix a crasher when a window is closed while the view is loading
  + Fix unmounted mounts showing in shell search provider results.
* Mon Sep 24 2012 dimstar@opensuse.org
- Remove gnome-shell BuildRequires: we only pull it in for
  directory ownership. Requiring it though introduces a buildloop.
  It's cleaner to just own the gnome-shell extension directories
  by gnome-shell-search-provider-nautilus.
* Tue Sep 18 2012 zaitor@opensuse.org
- Update to version 3.5.92:
  + Add a Shell search results provider.
  + Add a NautilusDirectory-based search engine implementation for
    network directories.
  + Improve performance and stability of the search engine.
  + Change the Type column to only show basic type information.
  + Preserve view selection when exiting search.
  + Use a symbolic icon for the location entry.
  + Fix wrong order of files when searching in canvas view.
  + Fix inability to drop on current directory in list view.
  + Fix crash when trying to undo failed directory creations.
  + Fix positioning of detached tabs.
  + Fix symlink creation for remote shares.
  + Fix duplicate entries in the sidebar.
  + Fix inability to clear entry in Connect to Server dialog.
  + Fix view selector flashing while switching views.
  + Plug a number of memory leaks.
  + Tweak the color scheme for the pie chart in mount properties.
  + Remove the SELinux context column for list view.
- Create a gnome-shell-search-provider-nautilus subpackage, for
  the new GNOME Shell search provider D-Bus service.
- Add gnome-shell BuildRequires to own new folders.
- Drop check for obsolete versions of opensuse.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + New design for the Connect to Server dialog.
  + Add the possibility to detach tabs using drag and drop.
  + Add paste and location properties actions to the gear menu.
  + Use symbolic icons in the sidebar for drives and mounts.
  + Follow 12h/24h GSettings preference for view date display.
  + Cleanup icon view caption strings.
  + Fix wrong zoom level restored at startup.
  + Fix unparented mount/eject error dialogs.
  + Fix drag and drop for unwritable locations.
  + Fix stray templates bar when no templates directory is defined.
  + Fix Open With menu showing for apps that don't support URIs and
    files.
  + Fix item count not updating in realtime for directories in
    Properties.
  + Fix missing keybindings for Back/Forward/Up/Go Home.
  + Fix missing history context menu on navigation buttons.
  + Fix missing Create Link context action.
  + Fix missing frame around custom icons.
  + Fix broken behavior with multiline filenames.
  + Plug a number of memory leaks.
  + Remove context menu on blank list view space.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Reorganize application and gear menu, and add a menu for view
    Actions
  + Add a View options selector to the toolbar
  + Add cluebars for Templates and Scripts special directories
  + Add ability to reorder bookmarks
  + Improve strings in the Autorun prompt
  + Improve error message strings
  + Improve the image Properties page
  + Improve the Permissions page in the Properties window
  + Improve the layout of the Bookmarks dialog
  + Use the dropped text paragraph as name when creating new files
    using DnD of text snippets
  + Use double quotes instead of ASCII quotes for filenames
  + Change default action for executable text files to Display
  + Change the view mode and zoom level to be per-window instead of
    per-folder
  + Remove support for Manual layouting in icon views outside of
    Desktop
  + Remove the Octal permissions list view column
  + Fix segfault when no search results are found.
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Combine results from both search providers.
  + Use a ranking algorithm for search results.
  + Preselect first search result.
  + Add a keybinding for the gear menu.
  + Improve styling for the search query editor.
  + Fix Ctrl+V not working correctly.
  + Fix previewers not being activated correctly.
  + Fix search not to trigger on the desktop window.
  + Fix pathbar scroll button styling bugs.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Add Copy To and Move To actions
  + Add a notification while ejecting volumes
  + List view:
  - New date format display
  - Use a list model instead of a tree model for list view
  - Use a better default column order
  - Change some list column names
  - Use 32px icons by default
  - Tweak padding
  + Search:
  - "Just type" search
  - Combine the search bar and the query editor
  - Tracker engine performance improvements and fixes
  + Sidebar:
  - Add a recent files place
  - Use symbolic icons
  - Improve order of the items
  + Toolbar:
  - Change toolbar layout to the GNOME 3 style
  - Don't show titlebar when maximized
  - Use a linked style for the pathbar
  + Menus:
  - Migrate the menubar to a gear menu
  - Remove "Go" menu
  - Remove "Bookmarks" menu
  + Remove "Text beside icons" option for icon view
  + Fix loading string not disappearing in image properties on load
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Fix accessibility implementation of rename entries and icon
    view.
  + Fix DnD not working on sidebar bookmarks.
  + Fix thumbnails failing to display in icon view.
  + Fix crasher after ejecting a volume from the sidebar.
  + Fix crasher on gtk-shell-shows-app-menu GtkSetting change.
  + Fix possible crasher when cancelling a rename operation.
  + Use GtkSearchEntry.
* Thu Jun  7 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Add a way to create a new directory for selection
  + Don't pack multiple x-content bars in the view
  + Show icons x-content bar application launchers
  + Hide New Document menu when no templates are installed
  + Remove statusbar
  + Remove "Go->Computer"
  + Remove compact view
  + Remove extra panes and tree sidebar
  + Fix pathbar buttons disappearing for too long titles
  + Fix sidebar typeahead find being triggered
  + Fix image properties label not wrapping for long width
  + Don't trigger context menu for sidebar headings
  + Don't show old 'note' emblems
  + Reintroduce GTK accel map loading/saving and migrate it to XDG
    dirs
  + Remove markup from GtkBuilder strings
* Wed May 16 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Add an application menu
  + Don't show sliders up to the file system root in the pathbar
  + Add support for AFP shares in the Connect to Server dialog
  + Don't remove selection when clicking on a row out of name
    boundaries
  + Fix a wrapping issue with numeric strings in some circumstances
  + Fix rename field selection color for backdrop state
  + Don't select all icons on Ctrl+A when the search entry is
    focused
  + Remove desktop-is-home-dir GSetting
  + Remove custom accel map loading/saving
  + Use new XDG location for GTK bookmarks file.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Fix a crasher when using network devices
  + Fix a crasher when entering "http" addresses manually in the
    location bar
  + Fix button packing for media content cluebar
  + Fix rename field selection color in backdrop state
  + Don't show context menus on sidebar headings
  + Don't remove selection when clicking on a row out of name
    boundaries
  + Fix a wrapping issue with numeric strings in some circumstances
  + Plug some memory leaks
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Don't display comment field for desktop files
  + Fix off-by-one error in file operation counts
  + Fix mouse hardware back/forward buttons not working correctly
  + Fix "Undo Trash" for files with non-ASCII characters
  + Fix name corruption for untitled files under some circumstances
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Fix a regression where "Open With" was hidden for folders
  + Updated translations.
* Mon Mar 19 2012 dimstar@opensuse.org
- Update to version 3.3.92:
  + Fix scrolling in compact view to work with latest GTK.
  + Fix Ctrl+Scroll zooming to work with latest GTK.
  + Don't hide Open With applications for subtypes of
    application/x-desktop.
  + Add support for the "network" GVolume class identifier.
  + Fix a crash at exit with certain extensions that keep refs of
    the NautilusFileInfos.
  + Fix initial focus row when moving the focus into the Places
    sidebar.
  + Fix Shift+Click selection when going back/forward in browsing
    history.
  + Fix packing of desktop file box in properties view.
  + Fix pathbar button sizing when a file watched by the pathbar
    changes name.
  + Fix properties window not being able to shrink size.
  + Remove unused --enable-profiler configure option.
* Mon Mar  5 2012 dimstar@opensuse.org
- Update to version 3.3.91:
  + Ensure pathbar scrolling works with latest GTK
  + Fix a crash when unmounting volumes with non-empty trash
  + Fix a race condition leading to a crash when closing window
    slots under certain circumstances.
- Replace libexempi-devel BuildRequires with pkgconfig(exempi-2.0).
- Remove gtk2-devel Requires from -devel package. It's been a while
  that nautilus is using gtk3.
- Remove glib2-devel Requires from -devel package: it is added
  automatically the pkgconfig() way.
- Drop nautilus-sysadmin-desktop-items.diff: the feature which this
  patch implemented is obsolete by now, as we do not have desktop
  icons by default anymore (bnc#533598).
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Don't make the inactive pane UI elements insensitive
  + Fix a crash when searching in list and compact view
  + Fix a crash when creating a file from a template
  + Use ngettext plural forms for undo strings
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + Introduce Undo support for common file operations
  + Fix a crash when middle clicking icons on the desktop
  + Fix split view actions not updating properly
  + Fix wrong places sidebar selection under some locales
  + Fix a crash when enabling desktop icons handling
  + Support build against Tracker 0.13/0.14
  + Make the rubberband animation obey the global GtkSetting
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Drop nautilus-tracker-0.14.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to gnome-autogen.sh:
  they were only needed for above patch.
* Thu Jan 19 2012 vuntz@opensuse.org
- Add support for tracker 0.13/0.14:
  + Add nautilus-tracker-0.14.patch.
  + Add call to gnome-autogen.sh, needed for above patch.
  + Change pkgconfig(tracker-sparql-0.12) BuildRequires to
    pkgconfig(tracker-sparql-0.14).
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Show both the current file counter and the total files in file
    operations UI
  + Lazily initialize the notification daemon
  + Move the UI files and icons into GResources
  + Refactor of NautilusWindowPane and NautilusWindowSlot code
  + libnautilus-extension GIR coverage has been improved
- Stop installing icons in /usr/share/pixmaps that we only needed
  to make some build checks happy, and that are unneeded now.
* Mon Dec 19 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Implement the org.freedesktop.FileManager1 DBus interface
  + Show context menu for current folder when clicking empty space
    in list view
  + Sort XDG dirs in the places sidebar according to the current
    locale
  + Fix handling of Ctrl+T on the desktop window
  + Fix icon view wrap-around key navigation
  + Fix rubberband scrolling in maximized windows
  + Fix a crasher when closing a window
  + Don't use deprecated GLib and GTK functions
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Fri Dec  9 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Nautilus-3_0 subpackage.
- Add typelib-1_0-Nautilus-3_0 Requires to devel subpackage.
* Wed Oct 26 2011 dimstar@opensuse.org
- Update to version 3.3.1.1:
  + No changes, only a fixed tarball release.
- Changes from version 3.3.1:
  + Show a Properties item in the sidebar for mounts
  + Use GtkStyleContext to draw editable label elements
  + Port to use GtkGrid
  + Don't use deprecated GThread API
  + Fix pie chart background rendering in Properties view
  + Fix a crasher when activating a sidebar item
  + Cleanup old libeel boilerplate code
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Consolidate typeahead find entry for icon view
  + Fix a crasher when middle-clicking empty space in the places
    sidebar
  + Fix a crasher when trying to delete files from the tree sidebar
  + Fix a crasher when ejecting a removable device under some
    circumstances
  + Fix a crasher when trying to activate the previewer in a list
    view with no selection
  + Fix a crasher when symbolic icon theme is not available
  + Plug some memory leaks
  + Fix the build when Tracker FTS is enabled
* Thu Oct  6 2011 vuntz@opensuse.org
- Add explicit shared-mime-info BuildRequires since we use the
  %%mime_database_* macros.
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Fix a couple of drawing regressions introduced in 3.1.92
  + Updated translations.
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Hopefully fix once and for all NautilusWindow keybindings
  + Don't hide the floating bar on hover if it's interactive
  + Fix canvas accessibility implementation for GTK 3.2
  + Don't warn when opening multiple files with one application
  + Correctly remember remote passwords when asked so
  + Add a new topic-based help menu
  + Fix default list view sorting order
  + Don't warn when a mount operation fails with ALREADY_MOUNTED
  + Select the item on right click in the Tree sidebar
  + Scroll to the selected file when opening an URI from the
    cmdline
  + Read the emblem icon names from the metadata
  + Use libtracker-sparql directly as an optional dependency
  + Streamline icon container rendering code to use gtk_render_*
  + Correctly remember "Keep Aligned" and other desktop metadata
  + Invalidate the text size when changing the DPI xsetting
  + Strip the hardcoded theme bits
  + Add Unity desktop file compatibility
  + Use XDG_CURRENT_DESKTOP when possible
- Add pkgconfig(tracker-sparql-0.12) BuildRequires: new dependency.
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Remove the built-in audio previewer.
* Wed Aug  3 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Remove the 'Create Launcher' options from the desktop
  + Improve the 'File System' entry in the places sidebar
  + Remove 'Clear History' from the 'Go' menu
  + Fix location bar not expanding full width in the toolbar
  + Use new g_format_size() instead of g_format_size_for_display()
- Drop nautilus-replace-deprecated-function.patch: fixed upstream.
- Drop nautilus-bnc363122-lockdown-context-menus.diff: as discussed
  upstream, in bgo#532228, this patch isn't really useful as
  actions are still available in the toolbar. So instead of
  pretending to offer a feature that is broken, it's better to not
  do anything.
- Drop nautilus-146947-rename-bad-parameters-message.diff: this was
  marked as needing a rebase, and the upstream bug (bgo#350976) now
  has a proper patch for gvfs.
- Drop nautilus-bgo350950-search-desktop.diff: we should use
  tracker-needle instead now, and possibly gnome-documents in the
  future.
* Fri Jul 29 2011 glin@suse.com
- Rebase nautilus-bnc363122-lockdown-context-menus.diff
- Add nautilus-replace-deprecated-function.patch to fix
  64bit-portability-issue from rpmlint
* Sat Jul  2 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Add an 'Add Bookmark' item in sidepane context menu
  + Fix --no-default-window not working when an URI is specified
  + Use g_cclosure_marshal_generic()
* Thu Jun 16 2011 vuntz@opensuse.org
- Add missing call to %%suse_update_desktop_file for
  nautilus-autostart.desktop.
* Wed Jun 15 2011 dimstar@opensuse.org
- Update to version 3.1.2:
  + Use GtkOverlay for the floating bar
  + Move the floating bar away from the cursor on hover
  + Add an autostart desktop file
  + Add metadata::custom-icon-name key for custom icons
  + Fix opening the wrong directory when launching an instance
    from the command line
  + Misc crashers.
* Wed Jun 15 2011 dimstar@opensuse.org
- Update to version 3.1.1:
  + Add a DBus previewer interface to support e.g. the Sushi
    previewer
  + Rework handling of _NETSCAPE_URL dnd links
  + Optimizations in the sorting/layouting code for Icon View
  + Misc bugfixes.
* Tue May 31 2011 fcrozat@suse.com
- Update to version 3.0.2:
  + Add an autostart desktop file.
  + Treat regular files as selection when opening a location.
  + Don't delete files when pressing Ctrl+Delete on rename.
  + Strip the method scheme in the connect to server dialog if
    possible.
  + Fix selection issues when navigating upwards.
  + Minor UI fixes.
- Package autostart .desktop file.
* Wed May  4 2011 vuntz@opensuse.org
- Update to version 3.0.1.1:
  + Fix some crashers
  + Don't show file transfer progress twice
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Fix white background bug when drawing desktop icons
  + Fix crash while ejecting volumes from the places sidebar
  + Fix enter not working in the places sidebar
  + Fix conflict dialog labels and entry sizing
  + Fix drawing artifacts in the search bar
  + Fix single click preferences mismatch
  + Fix additional details label colors when using a11y themes
  + Fix some minor/sporadic crashers
  + Fix libnotify and libexif version checks
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Use Ctrl+Delete as keyboard shortcut to trash files
  + Make sure we always open new windows from the desktop
  + Fix a crasher
  + Updated translations.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 2.91.94:
  + Fix eject button hover in places sidebar
  + Use new gnome-help pages for help buttons
  + Fix a crasher when toggling desktop_is_home_dir
  + Fix a memory leak
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + Memory leak fixes
  + Updated translations
- Changes from version 2.91.92:
  + Use a raised button for Search
  + Tweak the floating bar background
  + Only show the "Loading..." floating bar after half a second of
    loading.
  + Style cluebars according to mockups
  + Fix some split view regressions
  + Misc bugfixes
- Changes from version 2.91.91:
  + Allow the dbus manager to run as a service
  + Create folders in subdirectories in list view, when possible
  + Make sure we don't focus headers in the places sidebar
  + Don't activate 'Rename' in the sidebar for non-bookmarks
  + Fix the list view not updating anymore after creating an empty file
  + Fix regressions in rename widget focus
  + Fix some UI regressions from the latest changes
- Changes from version 2.91.90.1:
  + Make modules of extensions pulling in ORBit resident, to avoid
    ORBit's atexit()'s handler to call into unloaded code
  + Cleanup some unused code
- Changes from version 2.91.90:
  + Huge changes in the user interface, to match GNOME3 mockups
  + Remove the spatial mode
  + Updated tracker search engine to use libtracker-sparql
  + Consistently use "Home" instead of the username
  + Rename the GSettings schema path to /org/gnome/nautilus
  + Remove the ability for extensions to create toolbar items
- Remove nautilus-tracker-0.10.patch: fixed upstream.
* Sat Feb 19 2011 vuntz@opensuse.org
- Add nautilus-tracker-0.10.patch: add support for tracker 0.10.
  Without it, a search will be very expensive.
* Sun Feb 13 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
  + %%mime_database_post/postun because the package ships a mime
    type definition.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 28 2010 dimstar@opensuse.org
- Update to version 2.91.9:
  + Remove GConf dependency completely
  + Fade-out eyecandy for selection rubberband
  + Use notifications instead of a status icon for transfer progress
  + Change launcher name to 'Files'
  + Fix a couple of crashers and UI regressions
- Changes from version 2.91.8:
  + Propagate custom icons to bookmarks
  + Don't quit the application if there are file operations running
  + Better keynav in the places sidebar
  + Use symbolic icons for the notification area
  + Fix some drawing regressions while renaming
  + Fix issues with the default sort order selection
  + Completely remove GConf dependency
  + Large refactor of NautilusWindow/NautilusView architecture
  + Cleanup installed desktop files
  + Fix a couple of crashers
  + Build with GCC 4.6
- Changes from version 2.91.7:
  + Adapt to GTK+ 2.99.0 deprecations
  + Fix a crasher in the pathbar
  + Use a consistent name for the Home folder
  + Use a consistent name for the 'Create New Folder/Document'
    menu items
  + Build tweaks
- Changes from version 2.91.6:
  + Fix build with GTK+ 2.91.7
- Changes from version 2.91.5:
  + Tweak sidebar appearance with CSS
  + Remove 'exit-with-last-window' preference
  + Remove support for saving state with XSMP
  + Fix some UI GtkStyleContext regressions
  + Fix a11y for NautilusIconCanvasItem
  + Properly support '~' in the location bar
- Changes from version 2.91.4:
  + Port to the new GtkAppChooser widget family
  + Port to GtkStyleContext* Add DBus interfaces for copying files
    and emptying trash
  + Remove Beagle search support
  + Remove History and Notes sidebar
  + Use a new simpler debug infrastructure
  + Make the preferences an app-wide singleton window
  + Fix some drawing regressions
- Changes from version 2.91.3:
  + Remove autorun and automount machinery, it moved to
    gnome-settings-daemon
  + Don't install the 'File Management Properties' binary; there's
    now a capplet in gnome-control-center for the autorun system
    settings.
  + Fix interaction with the session manager
  + Don't use gtk_[h|v]_separator_new
  + Identify OGG Vorbis files as music in the search UI
  + Require new gnome-desktop
- Changes from version 2.91.2:
  + Use GSettings for desktop background
  + Cleanups of the emblem-related code
  + Fix some bad interactions with GApplication
  + Fix an annoying crasher
- Changes from version 2.91.1:
  + Fix a number of GTK+ 3 regressions
  + Port to the new GApplication API
  + Add a settings key to make the background fade effect optional
  + Add a settings key to register an external mass-renamer
  + Drop support for old EXIF/XMP APIs
  + Move the nautilus-sendto extension module in-tree
- Changes from version 2.91.0.1:
  + Fix a crash related to GtkSpinner
  + Fix the filename cell renderer to use the new GtkSizeRequest
    functions
- Changes from version 2.91.0:
  + New UI for the 'Places' sidebar
  + New UI for the 'Connect to server' dialogue
  + Highlight the eject button upon hovering in the Places sidebar
  + Make file conflict dialog strings I18N-friendly
  + Port to GTK3 new drawing functions
  + Cleanup background-related code
  + Various crashers and glitches fixes
- Changes from version 2.90.1:
  + Port to GSettings
  + Port to cairo drawing
  + Remove the "Backgrounds and Emblems" feature
  + Use GEmblemedIcon to draw icon emblems in list/tree views
  + Cleanup of libeel's obsolete code
  + Always show free space in the status string
  + Disable icon scaling outside the desktop
  + Various minor UI fixes
- Remove nautilus-bnc117333-bgo350962-folder-icon-for-menus-and-windows.diff:
  fixed upstream.
- Remove nautilus-boot-order.patch: no longer needed as session
  support was dropped.
- Disable nautilus-bnc363122-lockdown-context-menus.diff:
  need rebase.
- Disable nautilus-bgo350950-search-desktop.diff: need rebase.
- Remove use_tracker macro as beagle support was dropped.
- Replace GConf2 schemas handling with GSettings schemas handling,
  with %%glib2_gsettings_schema_* macros.
- Add pkgconfig(libnotify) BuildRequires.
- Remove pkgconfig() BuildRequires: gconf-2.0, unique-1.0.
- Change pkgconfig() BuildRequires for GNOME 3 port:
  + Old ones: gail, gnome-desktop-2.0, gtk+-2.0.
  + New ones: gail-3.0, gnome-desktop-3.0, gtk+-3.0.
- Add dbus-1 BuildRequires for directory ownership.
* Wed Dec  8 2010 vuntz@opensuse.org
- Update to version 2.32.2:
  + Fix a crasher
  + Updated translations.
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 2.32.1:
  + Fix a crasher when unmounting volumes
  + Updated translations.
* Mon Oct 11 2010 vuntz@opensuse.org
- Update baselibs.conf to use libnautilus-extension1 instead of
  nautilus: we care about the library here.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.32.0:
  + Fix places sidebar sometimes not changing location when
    clicking on a place
  + Fix various crashers
  + Updated translations.
* Mon Sep 13 2010 dimstar@opensuse.org
- Update to version 2.31.92:
  + String fixes for the file conflict dialog
  + Add a border around infobars
  + Fix a regression when copy/pasting in list view
  + Re-use libunique instead of GApplication
  + Drop GDK_DISABLE_DEPRECATED cflag, as we don't want to cope
    with recent GDK 2.22 deprecations for the 2.32 branch
- Re-add pkgconfig(unique-1.0) BuildRequires.
- Remove the sed hack for deprecated symbols and remove
  disable-maintainer-mode from configure call.
- Drop nautilus-no-disable-deprecated.patch: fixed upstream.
* Wed Sep  8 2010 vuntz@opensuse.org
- Remove unneeded gnome-desktop Requires: there's no reason for it.
* Tue Sep  7 2010 vuntz@opensuse.org
- Add libselinux-devel BuildRequires to build with SELinux support.
- Change old-style BuildRequires to pkgconfig() style
  BuildRequires:
  + old-style: gnome-desktop-devel, libexif-devel, libxml2-devel.
  + new-style: gail, gconf-2.0, glib-2.0, gnome-desktop-2.0,
    gtk+-2.0, libexif, libxml-2.0, pango.
- This will make it easier to switch to GNOME 3 libraries.
* Mon Sep  6 2010 vuntz@opensuse.org
- Do not add unneeded categories to
  nautilus-file-management-properties.desktop, especially since
  they make the item appear twice in the menus.
* Wed Aug 18 2010 dimstar@opensuse.org
- Update to version 2.31.90:
  + Don't make pathbar buttons disappear when deleting a folder
  + Remove useless unique-1.0 dependency
  + Don't use deprecated GtkNotebookPage
  + Translation updates
- Remove libunique-devel BuildRequires.
- Pass --disable-maintainer-mode to configure to have deprecated
  gdk/gtk symbols and sed GDK_DISABLE_DEPRECATED out of eel/*.
* Fri Aug 13 2010 dimstar@opensuse.org
- Update to version 2.31.6:
  + This release is based on 2.30.1
  + A long list of fixes have been backported from the master
    branch, including:
  - Expand and collapse folders with +/- in list view
  - Rename .desktop files also change their name on disk
  - Support overriding .gnome2 directory
  - Save passwords for the session by default
  - Remove deleted folders from the pathbar
  - Replace libunique with GApplication
  - Don't show 'File Browser' anymore in the window title
  - Port to GDBus
  - Change the default order for files in special directories
  - Support relative paths in the location entry/dialog.
  - Use folder icons as window icons in browser and spatial mode
  - Add 'Trashed On' and 'Original Location' columns in the
    trash
  - Implement transparent icons for cut files
  - Change default thumbnail size
  - Fix a number of bugs related to bookmarks
  - New dialog to handle conflicts within file copy/move
    operations
  - New button in the trashbar to restore selected items
  - Use async I/O to save .gtk-bookmarks
  - Fix a number of issues related to DnD in the places sidebar
  - New icon for audio preview
  - Don't show Unmount when showing Eject/Safe Removal
  - Bump libnautilus-extension API version
  - Fix a number of UI glitches
  + Updated translations.
- Rebase patches:
  + nautilus-bnc117333-bgo350962-folder-icon-for-menus-and-windows.diff
  + nautilus-no-disable-deprecated.patch
- Add gobject-introspection-devel BuildRequires.
* Fri Aug  6 2010 vuntz@opensuse.org
- Split out libnautilus-extension1 to reduce packages dependencies.
  Thanks to Andrea Florio <andrea@opensuse.org>.
- Add nautilus-no-disable-deprecated.patch to fix build with recent
  versions of GTK+ that have more deprecations.
- Make the build verbose.
- Improve summaries and descriptions.
* Mon Jun 14 2010 vuntz@opensuse.org
- Do not change the nautilus-browser, nautilus-computer,
  nautilus-home, network-scheme .desktop files: they have
  OnlyShowIn=GNOME and they are not supposed to be visible (but
  they became visible because we changed them).
- Do not change the nautilus .desktop file: it has NoDisplay=true
  anyway.
- Update nautilus-bgo350950-search-desktop.diff to have
  OnlyShowIn=GNOME; and do not change nautilus-search.desktop with
  suse_update_dekstop_file since this item is not visible in the
  menus.
* Wed May 26 2010 sshaw@decriptor.com
- Pulled a patch from SLED. nautilus-boot-order.patch
  Delays applets loading
* Wed May 26 2010 vuntz@opensuse.org
- Comment out the BuildRequires on tracker-devel to avoid
  triggering a build loop.
* Sun May 23 2010 vuntz@opensuse.org
- Change libbeagle-devel BuildRequires to tracker-devel on 11.3 and
  later as part of our move away from beagle. This is fate#307899.
  Note that nautilus loads the backend at runtime, so the
  BuildRequires is not really needed, except that it's useful for
  us, packagers, to remember that's what we want.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 2.30.1:
  + Support for tracker 0.8.0
  + Fix crashes
  + Fix emblem scaling in zoomed view
  + Fix sensitivity of split-view related menu items
  + Control-L closes the extra view first, not the window
  + Updated translations.
* Fri Apr  9 2010 vuntz@opensuse.org
- Change gvfs Requires to Recommends to avoid a build loop. Thanks
  to Michael Meeks for finding this!
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 2.30.0:
  + By default, don't exit with last window even if desktop is not
    visible. This way we still run to handle e.g. volume
    monitoring. If you don't want this, change
    /apps/nautilus/preferences/exit_with_last_window
    to True in gconf
  + Don't show weird border around desktop
  + Correctly put focus on view for new windows
  + Extra view does not get focus when created
  + Add nicer thumbnail border
  + Fix crash when hiding search bar
  + Fix build on sun compiler
  + Support AIFF for audio preview
  + Updated translations.
* Wed Mar 24 2010 vuntz@opensuse.org
- Add mount-archive.desktop to enable mounting an archive via gvfs,
  instead of opening it in file-roller. FATE#308344, bgo#602147.
- Stop creating %%{_libdir}/nautilus/extensions-1.0: we don't
  support extensions there anymore, so we shouldn't create the
  directory.
* Fri Mar 12 2010 dimstar@opensuse.org
- Update to version 2.29.92.1:
  + Fix compilation due to deprecated GTK_WIDGET_STATE symbol
  + Fix libm linking
  + Updated translations.
- Drop nautilus-gtk2.19.7.patch, fixed upstream.
* Mon Mar  8 2010 dimstar@opensuse.org
- Update to version 2.29.92:
  + Make view default focus in new windows
  + Put tabs at the top again
  + Don't use deprecated gtk widgets
  + Allow Alt-<num> to switch tabs
  + Dynamically load tracker support
  + Don't auto-close the window you initiated an unmount in
  + Updated translations.
- Add nautilus-gtk2.19.7.patch to properly build against gtk 2.17.9
  reported and sent upstream as bgo#612423.
* Mon Feb 22 2010 vuntz@opensuse.org
- Update to version 2.29.91:
  + Make it possible to have backgrounds spanning multiple
    monitors.
  + Better handling of closing windows when device is unmounted
  + Use GtkSpinner instead of custom widget
  + Updated translations.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 2.29.90:
  + Fix copy-pasted tooltip string
  + Translation updates
- Fix self-obsoletion of nautilus2 and nautilus2-devel.
* Mon Feb  1 2010 jengelh@medozas.de
- Package baselibs.conf
* Mon Jan 25 2010 vuntz@opensuse.org
- Update to version 2.29.2:
  + Align sidebar header and location bar
  + Remove tabs menu
  + Updated translations
* Fri Dec 18 2009 vuntz@opensuse.org
- Update to version 2.29.1:
  + Make browser mode the default
  + Add split view mode
  + Browser UI reorganization
  + Better background support on multi-monitor setups
  + Support new "default location" on mounts (supported by ftp and
    sftp)
  + Add extension api to lookup NautilusFileInfo objects
  + Make the search toolbar button a toggle button
  + Ctrl+shift does multiple range selection in list view
- Rebase
  nautilus-bnc117333-bgo350962-folder-icon-for-menus-and-windows.diff
  to apply without fuzz.
* Tue Dec 15 2009 dimstar@opensuse.org
- Update to version 2.28.4:
  + Fix bug in trash/delete key sensitivity fix that could cause
    data loss. (Files where trashed when you renamed a file and
    pressed delete.)
  + Fix uninitialized variable read.
* Mon Dec 14 2009 dimstar@opensuse.org
- Update to version 2.28.3:
  + Fix memory leaks
  + Don't rewrite bookmarks unnecessary on startup
  + Fix background "darkness" detection for font color
  + Disable trash/delete key shortcuts when menu items disabled.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update the way we remove the ha, ig locales for old versions of
  openSUSE.
* Tue Dec  1 2009 dimstar@opensuse.org
- Update to version 2.28.2:
  + Tracker: more robust for failure
  + bgo#598931 - Fixed "stuck" thumbnailing icon
  + Fix crash when renaming file to "" in list view
  + Support absolute filenames as icons in extensions again
  + Update UI correctly when inverting selection
  + Initialize show-hidden-files UI correctly depending
  + Fix free of uninitialized memory
  + Updated translations.
- Changes from version 2.28.1:
  + Correctly position icons for file drops
  + Fix lingering unmount menu item
  + Update tracker support for version 0.7
  + Fix crashes
  + Set correct recent files info
  + Make changing visible list view columns instant
  + Allow focusing the list view by clicking outside a line
  + Use right gconf key for the disable_tabs setting
* Fri Nov 13 2009 dimstar@opensuse.org
- Refresh nautilus-bnc363122-lockdown-context-menus.diff to apply
  with fuzz=0.
* Mon Sep 21 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Don't load non-images for thumbnailing when zoomed
  + Made desktop window a native x window for nicer redrawing
  + Fix leaks
  + Updated translations.
* Mon Sep  7 2009 lmedinas@opensuse.org
- Update to version 2.27.92:
  + Fix crash on logout
  + Always show app icon in open with popup menu
  + Fix duplicate id in ui file
  + Fix warning in new power manager inhibiting
  + Translation updates
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 2.27.91:
  + Migrate old-style nautilus metadata to gvfs metadata
  + Fix viewing of very small image files
  + Respect disable_command_line option
  + Reverse mouse button used for back/forward to same as firefox
  + Always show menu icons for menu items representing files
  + Inhibit suspend during file operations
  + Cancel audio preview when deleting the previewed file
* Sun Aug 16 2009 beineri@opensuse.org
- Fix menu entry to appear in System/File Manager category
  (bgo#592892).
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 2.27.4:
  + Add support for starting and stopping drives
  + Use the new GVfs metadata framework
  + Support new style unmount operations; this will provide a nice
    dialog when unmounting a busy drive mount
  + Add application icons to the Open With context menu
  + Reload xdg-user-dirs according to the user preferences
- Drop nautilus-build-fix.patch: fixed upstream.
* Wed Jun 17 2009 vuntz@novell.com
- Add nautilus-build-fix.patch to fix build with new GTK+.
* Tue Jun 16 2009 opensuse@sukimashita.com
- Update to version 2.27.2:
  + Support ctrl-drop in list view
  + Allow user defined keyboard shortcuts for extension items
  + Fix crash on click on toolbar
  + Fix crash on entering empty location
  + Added daemon-mode (don't exit with last window)
  + Display info about the selected item in the information sidebar
  + Sort applications in open with
- Respin nautilus-bnc363122-lockdown-context-menus.diff.
* Thu Jun 11 2009 vuntz@novell.com
- Remove libgnomeui-devel BuildRequires.
* Wed May  6 2009 vuntz@novell.com
- Update to version 2.27.1:
  + Drop GTK+ deprecated symbols
  + Display the application icon in the popup menu
  + Fix autorun hints for Win32 software media
  + Allow shift+return during typeahead find
  + Update desktop icons according to DPI changes
  + Use the correct folder icon fallbacks
  + Autogenerate ChangeLog and use shave to display the build
    output
- Update nautilus-bgo350950-search-desktop.diff and
  nautilus-bnc117333-bgo350962-folder-icon-for-menus-and-windows.diff
  so they apply.
- Use gnome-autogen.sh instead of autoreconf.
* Sun May  3 2009 mboman@suse.de
- Change BuildRequires from unique-devel to libunique-devel
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.2:
  + Fix issue with default dnd type when dragging to a parent
    directory
  + Fix icon view RTL layout in compact view
  + Make sure spatial geometry is always saved when closing windows
  + Save and load custom accelerator maps
  + Check for PackageKit before showing dialog using it
  + Add "location" column
  + Show both unmount and eject in menus for mounts that support both
* Sat Apr  4 2009 vuntz@novell.com
- Update to version 2.26.1:
  + Better handling of thumbnail scaling
  + Support XDS in list view
  + Make session loading work
  + Start Nautilus on requested screen
  + Fix crashes
  + Fix possible infinite layout loop in compact mode
  + Update fallback icon to not look like gnome 1.x
  + Fix some cases of sync i/o
  + Handle non-gvfs uris like e.g. mailto and http links with
    queries in links
- Remove AutoReqProv: it's default now.
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 2.26.0:
  + Fix crash due to broken gdk-pixbuf tga loader
  + Make sure thumbnails are updated even when zoomed up
  + Fix crash in media settings preferences
* Wed Mar 11 2009 vuntz@novell.com
- Update to version 2.25.93:
  + Use ConsoleKit to make sure we only autorun on active sessions
  + Never show unmount if we show an eject menu item
  + Show the gvfs reported owner/group names
  + Don't allow changing default app for folders
  + Fix "can't unmount same location twice" bug
* Fri Mar  6 2009 vuntz@novell.com
- Update to version 2.25.92:
  + Set mmap limit to avoid desktop background memory not being
    returned to the os
  + Warn when source overwrites destination in move
  + Don't put "link to ..." in front of symlinks unless there are
    name conflicts
  + Fix desktop flicker on theme change
  + Require desktop file app launchers to be executable
  + Support making symlinks on remote locations (if supported by
    backend)
* Mon Feb 23 2009 vuntz@novell.com
- Update to version 2.25.91:
  + Use G_DEFINE_TYPE_* instead of hand-written types
  + fix: opening a new window restores minimised ones
  + fix renaming of desktop files
  + Handle new kinds of GIcons
  + Don't display shadowed mounts
- Remove BuildRequires: fontconfig-devel
- Remove unneeded CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
- Remove unneeded chmod -x COPYING
- Add temporary workaround for broken gtk-doc: gtkdocize --copy
- Add --enable-gtk-doc configure flag.
- Remove "make nautilus.desktop src/network-scheme.desktop" since
  this was for a patch that we don't have anymore.
- Call suse_update_desktop_file on nautilus-browser.
- Stop packaging as docs some internal documentation that, IMHO,
  should not be part of a package.
- Update
  nautilus-bnc117333-bgo350962-folder-icon-for-menus-and-windows.diff
  to not have two Icon keys in nautilus.desktop.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Tue Feb  3 2009 mboman@suse.de
- Update to version 2.25.4:
  + Don't show desktop files from other desktops than Gnome on the
    desktop
  + Support crossfades of desktop backgrounds
  + Don't snap desktop icons outside right margin
  + Fix crashes and leaks
- nautilus-bnc366100-bgo338933-ignore-foreign-desktop-files.diff
  was removed. Fixed upstream
- Remove nautilus-456702-trash-restore.patch. Fixed upstream
  (See bgo#555234)
* Wed Jan 28 2009 vuntz@novell.com
- Manual merge from GNOME:Factory:Next, and update to 2.25.3.
- Update to version 2.25.3:
  + Remove CD/DVD creator from places menu and sidebar
  + Allow deleting custom emblems
  + Fix crashes
  + Don't show read-only emblems in trash
  + Trash performance fixes
  + General performance fixes
  + Update to new PackageKit API
- Changes from version 2.25.2:
  + Merged eel into nautilus
  + Use single glib/gtk includes
  + Support PackageKit application search
  + Fix new windows not appearing after successful mount
  + Remove support for old KDE trash dirs
- Changes from version 2.25.1:
  + Remove depencency on libgnome & gnome-vfs
  + Fix crashes
  + Chop trailing space characters when moving to FAT file system
  + When DnD'ing, COPY instead of MOVE, when the source is not
    deletable
  + Don't set default when opening with other app, just add to open
    with list.
  + Don't make copies of files from readonly source (e.g. CDROM)
    readonly
  + Don't show cancel dialog when showing the "run or display"
    dialog
- nautilus-sysadmin-desktop-items.diff needs to be rebased.
- nautilus-146947-rename-bad-parameters-message.diff also needs to
  be rebased, also someone needs to investigate if it's still
  needed.
- Drop nautilus-genericname.patch: we use %%update_desktop_file.
- Drop nautilus-new-windows-after-mount.patch: fixed upstream.
- Drop nautilus-disable-zoom-control-and-view-as-option-menu.patch:
  we don't want to diverge from upstream like this. Fix bnc#462077.
- Drop nautilus-181941-i18n.patch: it's already fixed upstream, and
  the patch was respinned without any reason.
- Drop nautilus-212649-search-bar-visibility.patch: the search bar
  is visible when you go to x-nautilus-search:/// and we didn't
  apply the patch anyway.
- Drop nautilus-330298-297983-fix-overlapping-desktop-icons.diff:
  the patch wasn't applied and it's been fixed upstream since quite
  some time.
- Merge nautilus-desktop-icon.patch in
  nautilus-bgo350950-search-desktop.diff since it's what it was
  patching.
- Update
  nautilus-bnc366100-bgo338933-ignore-foreign-desktop-files.diff
  to use GKeyFile.
- Trivial update to
  nautilus-bnc117333-bgo350962-folder-icon-for-menus-and-windows.diff
- Remove useless BuildRequires: cdparanoia, eel-devel (included in
  nautilus now), gvfs-devel, libidl-devel, librsvg-devel, and
  perl-XML-Parser.
- Note: we keep libgnomeui-devel because the included libbackground
  needs it.
- Add BuildRequires on libxml2-devel and unique-devel.
* Wed Jan 28 2009 vuntz@novell.com
- Updated nautilus-456702-trash-restore.patch to use the patch
  committed upstream.
* Thu Jan 22 2009 mxwu@novell.com
- Added nautilus-456702-trash-restore.patch (bnc#456702)
* Fri Dec  5 2008 hpj@novell.com
- Added nautilus-new-windows-after-mount.patch (bnc#437780,
  bgo#524485).
* Sun Nov 30 2008 vuntz@novell.com
- Remove sles_version conditional; make nautilus-search.desktop
  mandatory on SLES/SLED.
  (This was initially done by Federico, but I redid it to remove
  both %%sles_version)
* Wed Nov 12 2008 federico@novell.com
- Updated nautilus-sysadmin-desktop-items.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=438277 - icon positions
  in the desktop don't get restored.
* Fri Nov  7 2008 jpr@novell.com
- Add --no-desktop to nautilus search desktop file patch (bnc#439475)
* Wed Nov  5 2008 federico@novell.com
- Updated nautilus-sysadmin-desktop-items.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=438809 - Nautilus was
  crashing when files got cut-and-pasted to the desktop.
* Wed Oct 29 2008 rodrigo@novell.com
- Remove nautilus-mime.patch, not needed anymore
* Tue Oct 21 2008 maw@suse.de
- Update to version 2.24.1:
  + Fix saving of spatial window geometry on close
  + Remove trailing spaces on filenames when copying to FAT file
    systems
  + Allow emblems that don't start with "emblem-"
  + On unmount close tabs that show the unmounted location
  + Fixed redraw issues with labels on zoom
  + Don't toggle sidebar splitter when dragging it
  + Fix bookmark issue that sometimes led to locations not loading
  + Don't show the "cancel" dialog after a timeout when displaying a dialog
  + Fix crashes and leaks
- Respin nautilus-bnc366100-bgo338933-ignore-foreign-desktop-files.diff.
* Tue Oct 21 2008 federico@novell.com
- Updated nautilus-sysadmin-desktop-items.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=436750 - the built-in
  desktop links like Home, Trash, and volumes were not being shown at
  all.
* Thu Sep 25 2008 federico@novell.com
- Removed nautilus-bnc368446-network-in-places.patch to fix
  https://bugzilla.novell.com/show_bug.cgi?id=428968 - the Places
  sidebar had two "Network" items, as this patch had already been
  merged in the baseline sources.
* Mon Sep 22 2008 maw@suse.de
- Update to version 2.24.0:
  + Icon/compact view:
  * Follow run-time changes to set of icon text attributes to
    be displayed
  * Invalidate icon label when changing zoom level or “text
    besides icon”
  + List view:
  * Properly offer textual drag target
  + Request centered autorun dialog
  + Always sort folders before files, even if sort criterion is
    reversed
  + Always assume that trash directories are local.
* Mon Sep 22 2008 federico@novell.com
- Added nautilus-sysadmin-desktop-items.diff.  With this, the sysadmin
  can set the /apps/nautilus/desktop/predefined_items_dir key in GConf
  to point to a directory that holds .desktop files.  These desktop
  items will be shown in users' desktops.
* Wed Sep 10 2008 maw@suse.de
- Update to version 2.23.92:
  + Icon/compact view:
  * Allow to select range in addition to current selection, when
    pressing ctrl and shift at once )not yet possible in list
    view)
  * Fix layout timestamp storage when moving items around on
    desktop
  + List view:
  * Default to reverse sort order for date columns (i.e. recent
    to old)
  + Improve the “Clear History” confirmation dialog
  + Use GdkAppLaunchContext instead of EelAppLaunchContext
  + Fix small leaks.
* Wed Sep  3 2008 mboman@novell.com
- Update to version 2.23.91:
  + Make autorun work for blank media
  + No more pixelated SVGs displayed for desktop items with absolute icon
    SVG paths
  + Use consistent labels, mnemonics and icons for trash and delete actions
  + Icon container (i.e. icon view and compact view)
  * RTL support for vertical layout
  * Always reveal entire rows or columns of icons
  * Nicer icon container bounds
  * (Again) vastly improved keyboard navigation, especially in RTL mode
  * No more overlapping desktop icons, when files are added or volumes
    mounted while Nautilus is not running. This is implemented with
    metadata timestamps when the desktop icons are laid out.
  * Rewrite large chunks of icon canvas text size handling
  * Clear underlying items if hovered or selected item overlaps them
  + List View
  * Make scripts work when items in nested list view subdirectories are
    selected
  + Usual minor fix & polish galore
* Thu Aug 28 2008 maw@suse.de
- Update to version 2.23.90:
  + Truncate long item labels in the icon view and on the desktop
  * icon_view/text_ellipsis_limit and desktop/text_ellipsis_limit
    GConf preferences added (defaults to three lines)
  * expand when hovering, or when selecting a file
  + Support restoring of multiple items from trash at once
  + Handle scroll events on the path bar
  + Fix "same file system:.e. copy vs. move) DND check for
    desktop
  + Fix search for content type in simple search backend
  + Fix running of scripts on the desktop
  + Use more archive file types for file-roller integration for
    remote locations
  + Consolidate zoom handling internals
  + Show file name instead of URI in the bookmark editor window
    for local files
  + Polish "Visible Columns" list view dialog.
* Fri Aug  8 2008 maw@suse.de
- Update to version 2.23.6.1:
  + Support transferring files with reserved FAT characters to a
    FAT file system; replace them with an underscore if neccessary
  + Use x-content/* MIME type to associate applications with
    hotpluggable media
  + Path bar:
  * enable control-left click and middle-click interaction for
    path bar buttons
  * dynamically handle hierarchy changes in the path bar
  + Icon view keyboard navigation
  * Use linear selection instead of rectangle selection in when
    pressing shift
  * Still offer rectangular selection when pressing ctrl and
    shift
  * Only wrap around horizontally in horizontal layout mode
  * Only wrap around vertically in vertical layout mode
  * Never wrap around when in rectangle selection
  + Icon view now remembers last position when reloading in vertical
    layout
  + List view: Do not request mass redraw when dragging
  + Clear display name when changing file name
  + Only show "... All" actions ("Skip All", ...) in file operation
    dialogs if more than one file is transferred
  + Identify to GNOME session as file manager, not as generic
    desktop application
  + Fix display name of computer:// icons
- Respin nautilus-bnc117333-bgo350962-folder-icon-for-menus-and-windows.diff.
* Wed Jul 23 2008 maw@suse.de
- Update to version 2.23.5.1:
  + Add tab support to browser mode
  + Add "restore from trash" functionality (only per item)
  + Path bar and notebooks can be used as fully functional URI
    drop targets
  + Places sidebar:
  * Add eject buttons to volumes
  * Fix bookmark reordering
  * Make DND indication consistent with GTK+ file chooser
  + Async I/O
  * Use NautilusFile instead of GFile for path bar display
    name
  * Use NautilusFile for DND "same FS" check
  + Fix navigation where window was inconsistently "stuck"
    between two directories, i.e. the view was not completely
    changed
  + Always grab focus on location change, even if view is reused
  + Icon view fixes
  * If no icon is selected, but an icon has the keyboard focus,
    select it when pressing space.
  * Move keyboard focus after a file has been removed
  * Fix double-clicking of half-shown items
  + Thumbnailing changes
  * Never scale up any thumbnails
  * Compose and scale thumbnails on the fly
  * Speed up loading of large image files used as their own thumbnails
  + Display emblems for small icon sizes
  + Offer clipboard contents as text/uri-list
  + Use UTF-8 dash for properties window instead of "--"
- Drop nautilus-bnc397852-huge-memory-leak.patch, as it's now
  upstream.
* Fri Jul 18 2008 rodrigo@suse.de
- Fix typo in patch tags
* Fri Jun 27 2008 maw@suse.de
- Remove bogus symlinks (watch out for any missing icons).
* Fri Jun 20 2008 maw@suse.de
- Update to version 2.23.4:
  + Support new gnome-session autostart semantics
  + Add initial Gtk-doc support
  + Many other improvements; for a fuller account, see the NEWS
    file
  + Updated translations
  + Drop obsolete patches:
  nautilus-bgo364843-name-copy-dont-overflow-max-path-len.diff,
  nautilus-bnc376070-null-exifdata-crash.patch, and
  nautilus-bnc393226-dont-move-to-burn.patchn
  + Respin the following patches:
  nautilus-bnc366100-bgo338933-ignore-foreign-desktop-files.diff
  and nautilus-bnc363122-lockdown-context-menus.diff.
* Sat Jun  7 2008 hpj@suse.de
- Back out nautilus-bnc376669-always-update-thumbnail.patch
  (bnc#376669).
* Fri Jun  6 2008 rodrigo@suse.de
- Add nautilus-bnc397852-huge-memory-leak.patch (bnc#397852)
* Wed May 21 2008 hpj@suse.de
- Add nautilus-bnc393226-dont-move-to-burn.patch (bnc#393226).
* Tue May 20 2008 hpj@suse.de
- Add nautilus-bnc376669-always-update-thumbnail.patch (bnc#376669).
* Thu May  1 2008 hpj@suse.de
- Removed previously disabled patches that were made obsolete by
  upstream changes:
  * nautilus-default-thumbnail-size.diff
  * nautilus-6014-network-servers-in-places-sidebar.diff
- Added nautilus-bnc376070-null-exifdata-crash, which fixes
  crashes when showing the properties of a picture (bnc#376070).
* Mon Apr 28 2008 federico@novell.com
- Rebased these patches:
  nautilus-bgo364843-name-copy-dont-overflow-max-path-len.diff
  nautilus-bgo350950-search-desktop.diff
  nautilus-bnc117333-bgo350962-folder-icon-for-menus-and-windows.diff
* Wed Apr 23 2008 vuntz@suse.de
- Rename nautilus-docpath.patch to nautilus-genericname.patch and
  drop the part of the patch adding a DocPath.
- Do not add DocPath to desktop files with
  %%suse_update_desktop_file
- Rationale: since the desktop files use the Core category, adding
  DocPath means putting the items in the yelp toc, which we don't
  want.
* Tue Apr 22 2008 vuntz@suse.de
- Add nautilus-bnc368446-network-in-places.patch to add network://
  in the places sidebar. Fix bnc#368446 (backported from upstream
  2.23.1).
* Thu Apr 10 2008 maw@suse.de
- Update to version 2.22.2:
  + Add NautilusFileInfo APIs: can_write(), get_mount(),
    get_parent_info()
  + Do not try to autorun autorun.exe and autorun.inf
  + Automount in idle callback rather than at startup to improve
    user experience
  + Properly inhibit automount on startup, or for long login procedures
  + Do not automount directories in hidden hierarchies
  + Fix scrollbar display bug in "text besides icon" icon view mode
  + Do not thumbnail unreadable files
  + Correctly display bookmark icons
  + Fix blurry property window icon
  + Fix bookmark editing window.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 hpj@suse.de
- Upgraded to version 2.22.1:
  * Fix crashes and leaks.
  * Fix emblem display in property page.
  * Fix mime choosing to not always create application/x-ext-<extension> type.
  * Actually mount location in external connect to server dialog.
  * Fix thumbnail size limit checks.
  * Fix "show hidden" to also show backup files
    (was broken in some situations).
  * Verify that tracker is running before using it.
  * Fix desktop file icon handling with absolute filenames.
  * Use GDesktopAppInfos to launch desktop files.
  * Don't follow symlinks for deep file count.
  * Fix audio preview with later gstreamer.
  * Make "move file over directory" overwrite case work.
  * Sometimes we failed to ask for overwrite when move
    operations falled back to copy + delete.
  * Make sure we correctly transcode filenames when merging
    directories if the directory is on another filesystem.
  * Some moves were reported as copies, not moves in the ui
    which could cause not up-to-date directory displays.
  * Don't center file progress dialog if its already displayed.
- Remove obsolete patch nautilus-bnc366455-change-ownership.patch.
* Fri Mar 28 2008 federico@novell.com
- Removed nautilus-158158-ignore-foreign-desktop-files.diff; it is obsolete.
- Added nautilus-bnc366100-bgo338933-ignore-foreign-desktop-files.diff
  to fix https://bugzilla.novell.com/show_bug.cgi?id=366100 - Desktop
  links with "OnlyShowIn=KDE" are now ignored.
* Fri Mar 21 2008 jpr@suse.de
- Add back gtk2-devel to the devel requires
* Fri Mar 21 2008 vuntz@suse.de
- Add a gnome-desktop-devel buildrequires to fix the build.
* Fri Mar 21 2008 jpr@suse.de
- Remove obsolete -devel package requries
- Remove medusa obsoletes, not  relevant to any shipping distros
* Thu Mar 13 2008 sbrabec@suse.cz
- Custom look'n'feel gconf keys moved to gconf2-branding-openSUSE.
* Thu Mar 13 2008 vuntz@suse.de
- Update to version 2.22.0:
  + Fix typo in strings
  + Fix crashes
  + Use a better icon for the progress dialog
  + Have a mount menu for mountable files, not an unmount one
  + Handle broken bookmark files bette
  + Sniff x-content type asynchronously
  + Don't look for autorun stuff on non-local files
  + Allow setting permissions on remote shares
  + Fix "delete all" button in delete dialog
  + Show custom icons at right size
  + Fix some performance issues on nonlocal mounts
- Drop nautilus-onlyshowin.patch, fix upstream.
- Use %%suse_update_desktop_file for nautilus-autorun-software and
  nautilus-folder-handler to mark them as translatable.
- Add nautilus-bnc366455-change-ownership.patch to fix bnc#366455.
* Wed Mar  5 2008 maw@suse.de
- Update to version 2.21.92:
  + Build fixes
  + Fix crashes and leaks
  + Fix handling of desktop file launchers
  + Better handling of desktop file icons
  + Semitransparent DnD icon support (when composited)
  + Avoid showing progress info when dialogs are shown
  + Allow minimize of progress window
  + Handle beagle >= 0.3.0
  + Close properties dialog on escape
  + Make custom icons work again
  + Fix fuzzy icons
  + Duplicate file if copies to the source directory
  + Support open with dialog for multiple selected files
  + Ressurect connect to server dialog
  + Allow theming of free diskspace chart colors.
* Thu Feb 28 2008 rodrigo@suse.de
- Added tags for all upstreamed patches, as well as bug numbers for
  all patches
* Wed Feb 20 2008 federico@novell.com
- Added nautilus-bnc363122-lockdown-disable-context-menus.diff to implement
  https://bugzilla.novell.com/show_bug.cgi?id=363122 - have a way to disable
  context menus in file views for quick-and-dirty kiosk setups.
* Wed Feb 20 2008 maw@suse.de
- Update to version 2.21.91:
  + String cleanups
  + Inhibit autorun for things we mount ourselves
  + Fix crashes and leaks
  + Only show selinux context if selinux is detected
  + Default to move, not copying, when dragging from the trash
  + Don't autorun/automount non-local mounts
  + Fix case where we could run out of file descriptors
  + Handle drop of files on the desktop
  + Fix sensitivity of delete from the trash menu item
  + Fix open w/ context menu in always-use-browser mode.
* Wed Feb  6 2008 maw@suse.de
- Explicitly require gvfs (bnc#358748).
* Tue Feb  5 2008 jpr@suse.de
- Add XMP support (bnc #310430)
* Wed Jan 30 2008 maw@suse.de
- Add extensions-2.0 directory.
* Tue Jan 29 2008 maw@suse.de
- Update to version 2.21.90:
  + Regenerate thumbnails when files change
  + Fix crashes
  + New autorun and automount support
  + Allow unmount of current location if its a mountpoint
  + Use thousand separators in all numbers (if used by locale)
  + Fix leaks
  + Performance improvements
  + Update to latest glib APIs
  + Fix bug that lost metadata from older versions
  + Fix crashes
  + Enable paste into folder for desktop icons
  + Better finding of autorun files on case sensitive media
- Remove libtool archives.
* Fri Jan 25 2008 maw@suse.de
- Update to version 2.21.5:
  + Totally replaced gnome-vfs use with gio
  + New implementation of file operations like copy/move with
    a shared progress dialog
  + Update pkg-config files with new extensions dir
  + Handle dnd of desktop icons
  + Implement some missing unmount/eject operations
  + Add autorun/automount feature
  + Better handling of sensitivity of delete menu items
  + Better handling of mount/unmount/eject in many places
  + Fix for extensions with submenus.
* Fri Jan 18 2008 jpr@suse.de
- Updated nautilus-drives-and-volumes-on-desktop.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=335411 - Nautilus
  crashes when it gets a "volume-mounted" signal for a volume that is
  already mounted.  This also adds two new logging domains to Nautilus:
  "drives-volumes" and "desktop-links".
* Thu Oct 11 2007 sbrabec@suse.cz
- Removed bogus dependency on mDNSResponder.
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 2.20.0:
  * Load thumbnails asynchronously
  * Support direct save DnD (XDS)
  * Fix up octal permission display
  * Store window keep-above and stickines state across sessions
* Wed Sep  5 2007 maw@suse.de
- Don't require gnome2-user-docs, which now supplements
  nautilus (#297833).
* Wed Aug 29 2007 maw@suse.de
- Update to version 2.19.91:
  * Be more robust against broken extensions
  * Set current working directory right on desktop when running scripts
  * Fix crash on file:///#
  * Update to cope with the new size of emblem icons
  * Auto-size list view filename column again
  * New message for service unavailable error
  * UI terminology consistency fix
  * Build fix
- Refresh nautilus-search-desktop.patch.
* Thu Aug 16 2007 federico@novell.com
- Updated nautilus-drives-and-volumes-on-desktop.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=298802 - after burning a
  CD and re-mounting the CD, Nautilus uses 100%% CPU.  This simply
  includes the last patch from
  https://bugzilla.novell.com/show_bug.cgi?id=276193#c42
* Fri Aug 10 2007 federico@novell.com
- Added nautilus-330298-297983-fix-overlapping-desktop-icons.diff to
  fix https://bugzilla.novell.com/show_bug.cgi?id=297983 - desktop
  icons would overlap when inserting removable media, if the
  previously-saved location for the corresponding icon now has a
  different icon nearby.
* Mon Aug  6 2007 maw@suse.de
- Split out -lang subpackage
- Use %%fdupes.
* Wed Aug  1 2007 maw@suse.de
- Update to version 2.19.6
- Memory leaks plugged
- Crashes fixed
- Fixes to UI manager usage
- Better string ellipsation
- Consistent focus behaviour for toolbar buttons
- Support for XMP image metadata
- Improved keyboard handling in connect to server dialog
- I18n fixes and string clarifications
- Add more tooltips and use new gtk+ tootips API
- Better handling of unreadable directories during search
- Updated translations.
* Tue Jul 10 2007 maw@suse.de
- Update to version 2.19.4
- Fix crashes and leaks
- Fix hang with recursive symlinks
- Disk free piechart in properties dialogue
- Fix typos in warning and error messages
- Use new desktop capplet
- Better handling of unicode search terms
- Allow activating the zoom context menu by keyboard
- Allow renaming network servers' icons
* Thu Jun  7 2007 sbrabec@suse.cz
- Do not overwrite auto-generated files.
- Removed invalid desktop Category "Application" (#254654).
* Mon Mar 26 2007 sbrabec@suse.cz
- Fixed BuildRequires.
* Thu Mar 22 2007 maw@suse.de
- Update to version 2.18.0.1
- intltool is now a build requirement
- Several code cleanups
- Bug fixes, including p.g.o 408155, 333151, 358172, 408155,
  409276, 407150, 407618, and 368661.
* Tue Mar 13 2007 maw@suse.de
- Update to version 2.17.91
- Bug fixes, including bugzilla.gnome.org #364466, #403255,
  [#138058], #340495, #357955, #403565, #357955, #362034,
  [#385382], #394328, #329920, #320020, #327249, #389467, #376291,
  [#374623], #382207, #376952, #384078, #383840, #45953, #350579,
  [#318373], #132326, #372550, #338353, #372471, #330298, #155337,
  [#174766], #122688, #321175, #349840, #356124, #351713, #348161.
* Tue Feb 27 2007 dmueller@suse.de
- adjust BuildRequires: libexif->libexif-devel
* Mon Feb  5 2007 sbrabec@suse.cz
- Fixed Categories (#242053).
* Fri Jan 12 2007 mtgordon@suse.de
- Added nautilus-181941-i18n.patch to mark for translation a
  previously unmarked string (marked in other locations in the app,
  sparing the need for further l10n).  Fixes
  https://bugzilla.novell.com/show_bug.cgi?id=181941 and sent upstream
  at http://bugzilla.gnome.org/show_bug.cgi?id=394328
* Mon Dec 18 2006 sbrabec@suse.cz
- Prefix changed to /usr.
- Spec file cleanup.
* Tue Nov 21 2006 sbrabec@suse.cz
- Do not explicitly require mDNSResponder-lib blocking avahi compat
  package.
* Wed Nov  8 2006 federico@novell.com
- Updated nautilus-drives-and-volumes-on-desktop.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=215351.  Floppy icons
  disappeared from the desktop after unmounting the floppy.  This also
  fixes https://bugzilla.novell.com/show_bug.cgi?id=218910, where
  there was a race condition when mounting drives.  This caused the
  activation URIs of the corresponding NautilusFiles not to be updated
  correctly.
* Wed Nov  1 2006 federico@novell.com
- Removed nautilus-hide-desktop-files.patch.  This was used for the
  old "applications://" VFS scheme, which is deprecated now.
- Removed nautilus-submount.patch, since we no longer use submount (subfs).
- Removed nautilus-142860-vfs-drive-for-extensions.diff, since that
  feature appeared upstream since Nautilus 2.14.  This is what lets
  Nautilus extensions look at the GnomeVFSDrive for a file, so that
  they can install menu items specific to drives (e.g. like
  nautilus-cd-burner).
- Removed nautilus-172870-support-drives-and-volumes.diff and
  nautilus-155010-desktop-volume-policy.diff, since they need to be
  reworked for the code in Nautilus-2.16.
- Added nautilus-6014-network-servers-in-places-sidebar.diff, to fix
  the part of https://bugzilla.novell.com/show_bug.cgi?id=6014 that is
  not yet in Nautilus 2.16.  This adds a "Network Servers" item in the
  Places sidebar.
- Added nautilus-206369-desktop-icon-overlap.diff as an updated
  and consolidated version of
  nautilus-155337-icon-positioning-on-reload.diff and
  nautilus-174766-fix-lazy-positioning.diff.  This is to fix the bug
  where desktop icons get overlapped or rearranged when a new volume
  icon appears, or when the desktop is reloaded.
- Added nautilus-drives-and-volumes-on-desktop.diff as a partly
  updated version of nautilus-172870-support-drives-and-volumes.diff.
- Added nautilus-debug-log.diff.  This provides logging functionality
  to aid debugging.
- Updated descriptions inside the rest of the patches.
- Renumbered patches.
* Tue Oct 31 2006 joeshaw@suse.de
- Add a patch to ensure that the search entry bar is displayed
  when navigating to the x-nautilus-search:/// URI.  (bnc #212649)
* Sat Oct 14 2006 danw@suse.de
- Remove dead patches
* Mon Oct  2 2006 jhargadon@suse.de
- update to version 2.16.1
- Default to search in current directory for non-indexed search
- Fix clash with symbol names in gtk+
* Wed Sep 20 2006 sbrabec@suse.cz
- Update MIME database in scriptlets (#201729).
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 2.16.0
- Handle enter activation when using typeahead search
- Avoid using gnome_vfs_is_local in wrong places
- Translations
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 2.15.92.1
- Fix crash on startup
- Fix crash on changing owner/group of file
- Fix double free
- Make sure all strings are displayed translated
* Fri Aug 18 2006 jhargadon@suse.de
- update to version 2.15.91
- Use gtk recent files code
- Fix file change notification regression
- Don't display raw form of selinux contexts
- Import lates EggSequence with bugfixes
- DnD fixes
- Read .hidden symlinks
- Fix down navigation in last column, next to last row
- Submenu support for extensions
- Improved beagle daemon detection
- Enable D'n'D reordering in the places sidebar
- New icons for trash operations
- Add a button/text toggle button to the location bar
- Fix leak
* Mon Aug  7 2006 gekker@suse.de
- Update to version 2.15.4
- Remove upstreamed patches
  * New permission dialog with recursion and selinx support
  * Improve extension interface
  * Add complete session management
  * Handle removal of the displayed location more elegantly
  * Support dropping uris, urls and text to subfolders
  * Don't allow formating of mounted floppies
  * Perfomance fixes
  * Don't use deprecated eel features
  * Improve startup performance
  * Use GOption
  * Fix selection box width calculation
  * Improve file permission handling
  * Add volume operations to the file menu, tree and places sidebar
  * New po/LINGUAS handling
  * Smarter date handling for images
  * HIG fixes
  * Fix crashes
  * Fixes for icons and thumbnailing
  * Show network volumes in the places sidebar
  * Fix progress dialog showing the wrong file
  * Translation updates
  * Use --no-desktop option for all desktop files
  * Startup performance improvements
  * Make files copied from read-only source writeable
  * Don't allow bookmarking x-desktop:///
  * Add help buttons to several dialogs
  * Fix SVG file identification
  * Properly break down URIs for connect to server ui
  * Show unmounted but user-visible drives in the places sidebar
  * Display more info in the progress dialog when preparing
  * Smarter DnD target selection
  * GnomeGoals: Use po/LINGUAS
  * Fix deadlock when dragging over list view in some conditions
  * Don't show folder count for smb shares
  * Close window when folder moves to trash
  * Fix deep count in properties dialog in some cases
  * Avoid calculating mime lists for activation
  * Remove blank error dialog on mount when using gnome-mount
  * Better filename linebreaking at punctuation marks.
  * List view: If a rename moves the file in the view, scroll to the new position
  * Better handling of broken filename encoding for link targets
  * Browser mode: don't close window on up if current directory has been removed
  * Pass original files, not target files to property page providers.
  This allows property page extensions to look at desktop files and symlinks.
  * Fix opening saved searches file from outside nautilus
  * Add option to always use the location bar to the preferences dialog
  * Show detailed file size in the properties dialog
  * Open modules with BIND_LOCAL
  * Add Network to places menu
  * Fix sort by atime
  * Add support for searching for custom mime type
  * Much better activation of multiple files
  * Handle new background image zooming mode
  * Add optional support for Tracker indexer
  * Added initial support for search
  * Better handling of opening multiple files
  * View update optimizations
  * No titles for alert dialogs
  * Use access() to determine permissions
  * Fix mime list problem introduced with sort change
  * Finally fix tree sidebar crash
  * ctrl-shift-g goes backwards in typeahead
  * Add Skip all button in copy/move conflict dialog
  * Position new files/folders correctly in manual layout mode
  * Fix desktop redraw issues on non-100%% zoom levels
  * Adds volume/drive api for modules
  * GtkTreeView style typeahead
  * '/' opens location dialog/entry
  * middle click in browser mode opens new window
  * Handle cancellation of authentication better
  * Add format menu item for floppy drives
* Wed Jun  7 2006 jpr@suse.de
- Don't update the .desktop file if it doesn't exist
  (really fix #177551)
* Thu Jun  1 2006 federico@novell.com
- Added nautilus-172870-support-drives-and-volumes.diff.  This fixes
  https://bugzilla.novell.com/show_bug.cgi?id=172870 by adding proper
  support for displaying unmounted drives as well as mounted volumes.
  This also makes floppies work from the desktop.
- Added nautilus-174766-fix-lazy-positioning.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=174766.  This makes
  volume icons not overlap with other icons in the desktop when
  volumes get mounted.
* Mon May 22 2006 federico@novell.com
- Updated nautilus-158158-ignore-foreign-desktop-files.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=177777.  All .desktop
  files were being filtered erroneously if they didn't have
  OnlyShowIn/NotShowIn keys.
* Mon May 22 2006 joeshaw@suse.de
- Only patch in the nautilus-search.desktop file on SL, not SLE,
  since the new main menu has search built-in.  (bnc #177551)
* Wed May 17 2006 sbrabec@suse.cz
- nautilus-search-bar.c added to POTFILES.in.
* Wed May 17 2006 sbrabec@suse.cz
- Fixed I18N problems:
  * untranslatable Search string (#173448)
  * uninitialized locale (#173448#c3)
* Tue May 16 2006 federico@novell.com
- Updated nautilus-158158-ignore-foreign-desktop-files.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=176123.  The
  "OnlyShowIn" key in desktop files can contain multiple items.  Also
  pay attention to the "NotShowIn" key.
* Mon May 15 2006 federico@novell.com
- Added nautilus-158279-add-location-toggle-button.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=158279.  This adds a
  toggle button to the left of path bar in navigation windows.
  Pressing this button will switch to using a location entry instead
  of the path bar.
* Fri May 12 2006 federico@novell.com
- Updated nautilus-155010-desktop-volume-policy.diff; this fixes
  https://bugzilla.novell.com/show_bug.cgi?id=175076.  This fixes a
  crash when dragging a volume to the trash.
* Wed May 10 2006 joeshaw@suse.de
- Update search patch to remove annoying "queuing <whatever>"
  debug spew.
* Wed May 10 2006 federico@novell.com
- Added nautilus-142860-vfs-drive-for-extensions.diff to fix the
  Nautilus part of bug
  https://bugzilla.novell.com/show_bug.cgi?id=142860.  This lets
  Nautilus extensions see the drives that may correspond to desktop
  icons.
* Mon May  8 2006 federico@novell.com
- Added nautilus-66073-update-progress-dialog.diff to fix bug
  https://bugzilla.novell.com/show_bug.cgi?id=66073.  The progress
  dialog for file operations now gets updated correctly if several
  small files get copied before a large file.
* Mon May  1 2006 dobey@suse.de
- Added nautilus-trash-icon.patch to use the theme's trash icon,
  rather than the delete icon, for the "Move to Trash" menu items
* Thu Apr 27 2006 federico@novell.com
- Updated nautilus-155010-desktop-volume-policy.diff to fix bug
  https://bugzilla.novell.com/show_bug.cgi?id=168280.  This makes
  Nautilus not display two volume icons for no-media-check devices.
* Tue Apr 18 2006 federico@suse.de
- Removed dot-hidden.dif.  This fixes bug #158158 completely; that
  patch is obsoleted by the updated
  nautilus-158158-ignore-foreign-desktop-files.diff.
* Tue Apr 18 2006 federico@novell.com
- Added nautilus-158158-ignore-foreign-desktop-files.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=158158.  This makes
  Nautilus ignore .desktop files whose OnlyShowIn property indicates
  that they are specific to another desktop environment.
* Tue Apr 18 2006 joeshaw@suse.de
- Update nautilus-search patch to correctly handle a search URI
  being passed into nautilus on the command-line.  (bnc #166158)
* Mon Apr 17 2006 federico@novell.com
- Added nautilus-155010-desktop-volume-policy.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=155010.  This makes
  Nautilus display the same set of drives and volumes as GTK+'s file
  chooser.  It will also display certain drives on the desktop for
  easy access (in particular, drives that do not support notification
  of inserted media, so we always need them to be accessible through
  the GUI, as opposed to being automounted).
* Wed Mar 29 2006 sbrabec@suse.cz
- Handle inode/directory MIME type (#161824).
* Wed Mar 22 2006 dobey@suse.de
- Added nautilus-unscaled-sidebar-menu-icons.patch to avoid scaling
  icons in the sidebar and where those same icons are used in menus
* Mon Mar 20 2006 federico@novell.com
- Added nautilus-155337-icon-positioning-on-reload.diff to fix bug
  [#155337].  Now icons in the desktop are not repositioned if the
  desktop gets reloaded.
* Fri Mar 17 2006 federico@novell.com
- Added nautilus-perf-no-burn-uri-for-desktop.diff.  This makes
  Nautilus not do unnecessary work when initializing the desktop,
  saving 1 second during login.
- Added nautilus-icon-registration.diff.  This makes Nautilus do less
  work when registering its stock icons, saving about 1.5 seconds
  during login.
* Tue Mar 14 2006 ro@suse.de
- use beagle on ppc64 as well
* Thu Mar  2 2006 sbrabec@suse.cz
- Translations from upstream moved to gnome-patch-translation.
* Fri Feb 24 2006 federico@novell.com
- Added nautilus-130796-bad-icon-placement.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=130796.  This makes
  desktop icons with very wide labels be placed correctly, instead of
  being placed flush left with the edge of the screen.
- Removed nautilus-115467-dont-overlap-volume-icons.diff as it is
  integrated into the new patch.
* Wed Feb 22 2006 joeshaw@suse.de
- Update nautilus search patch to not display UI when beagled
  isn't running.
* Sun Feb 19 2006 aj@suse.de
- Reduce BuildRequires.
* Sat Feb 18 2006 gekker@suse.de
- ficup .desktop files for UI team
* Mon Feb 13 2006 federico@novell.com
- Added nautilus-130796-bad-icon-placement.diff to fix
  https://bugzilla.novell.com/show_bug.cgi?id=130796.  This makes
  desktop icons with very wide labels be placed correctly, instead of
  being placed flush left with the edge of the screen.
* Thu Feb  9 2006 federico@novell.com
- Updated nautilus-6014-network-servers-desktop-icon.diff.  Now we
  hide the "Network Servers" icon in the desktop by default, but we
  have new such items in the Places sidebar and the Go menu.  This
  fixes https://bugzilla.novell.com/show_bug.cgi?id=149685
* Wed Feb  1 2006 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation.
* Tue Jan 31 2006 federico@novell.com
- Added nautilus-146947-rename-bad-parameters-message.diff to fix bug
  [#146947].  If you try to use illegal characters when renaming a file
  in an SMB share, Nautilus will now give you a better error message
  instead of a generic "couldn't rename" one.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 joeshaw@suse.de
- Update search patch to only search the files backend
* Wed Jan 18 2006 gekker@suse.de
- Remove Requires: on control-center2 and gnome-themes (#142237)
* Tue Dec  6 2005 sbrabec@suse.cz
- Do not require beagle on ppc64.
- Enabled parallel build.
* Mon Dec  5 2005 federico@novell.com
- Removed nautilus-136167-no-default-window.diff.  This is not the right fix, as external
  apps rely on being to call just "nautilus" without command-line arguments, so that
  Nautilus will open a window showing your Home directory.  Moreover, there's no way for
  Nautilus to tell if it was (re)started by the session manager upon login, or as a result
  of exiting abnormally.
* Thu Dec  1 2005 federico@novell.com
- Updated nautilus-6014-network-servers-desktop-icon.diff.  When doing "Clean up
  by Name", the Network Servers icon will now be put after your Home icon.
* Thu Dec  1 2005 federico@novell.com
- Added nautilus-6014-network-servers-desktop-icon.diff to fix bug #6014.  This
  Creates a "Network Servers" icon in the desktop.
- Added nautilus-136167-no-default-window.diff to fix bug #136167.
  When restarted abnormally, Nautilus will no longer open a window for
  your home directory.
* Wed Nov 30 2005 gekker@suse.de
- Update to version 2.12.2
* Mon Nov 28 2005 gekker@suse.de
- Enable nauilus sidebar by default (#132383).
* Thu Nov 17 2005 federico@novell.com
- Added nautilus-default-thumbnail-size.diff.  This makes the default size for
  thumbnails be 64 pixels, which looks better with the default theme than the
  old value of 96 pixels.
* Mon Nov 14 2005 joeshaw@suse.de
- Update nautilus-search patch to 20051101.
- Add patch to hide the zoom and "view as" controls from the
  location bar.
* Tue Nov  8 2005 federico@novell.com
- Added nautilus-115467-dont-overlap-volume-icons.diff to fix part of
  bug #115467.  With this, Nautilus will not overlap the icons when
  you insert a CD or USB stick.
* Wed Nov  2 2005 federico@novell.com
- Updated nautilus-submount.patch to fix bug #127509.  With this, the
  "Unmount volume" command will appear again for network volumes.
* Thu Oct 13 2005 gekker@suse.de
- Update to version 2.12.1
- Remove upstreamed patch
- Re-diff some patches so that they apply to new version
* Fri Oct  7 2005 jpr@suse.de
- Update beagle search patch
* Thu Oct  6 2005 federico@novell.com
- Added nautilus-desktop-file-fallback-icons.diff so that .desktop
  files which don't have an Icon property will fall back to some
  reasonable icons depending on the type of the .desktop file.
* Thu Oct  6 2005 gekker@suse.de
-  Add DocPath to .desktop file
* Thu Oct  6 2005 sbrabec@suse.de
- Require gnome-themes.
* Wed Oct  5 2005 federico@novell.com
- Added nautilus-consistent-home-folder-name.diff to make the name of
  $HOME consistent between the path bar and side bar in Nautilus and
  GtkFileChooser.
* Thu Sep 22 2005 clahey@suse.de
- Turn off computer icon by default.
* Thu Sep 15 2005 clahey@suse.de
- Added nautilus-icon.patch to change main icon.  bug #117333
* Thu Sep  8 2005 federico@novell.com
- Added nautilus-114914-trash-unmount-removable-volume.diff to fix bug
  [#114914].  With this, trash windows will display the correct contents
  if there are mounted removable volumes.
* Thu Sep  8 2005 adrian@suse.de
- do not show up in konqueror menus (#115880)
- Computer menu entry broken other desktops
* Mon Sep  5 2005 gekker@suse.de
- Add submount patch (90584)
- Fix spec to apply both desktop search patches
* Mon Sep  5 2005 mmj@suse.de
- Update to version 2.12.0 (GNOME 2.12)
* Sun Aug 28 2005 jpr@suse.de
- Default to browser mode (113690)
- Add nautilus-search.desktop so gnome-panel has something to launch
  for file searches (113691)
* Tue Aug 23 2005 rodrigo@suse.de
- Update to version 2.11.92
* Tue Aug 16 2005 sbrabec@suse.cz
- Updated nautilus-search patch from Joe Shaw.
* Thu Aug 11 2005 gekker@suse.de
- Update to version 2.11.91
* Tue Aug  2 2005 gekker@suse.de
- Update to version 2.11.90
* Wed Jul 13 2005 sbrabec@suse.cz
- Updated to version 2.11.2.
- Added x-nautilus-search beagle integration patch.
- Removed static modules and .la files for libnautilus-private.
* Mon Jun 20 2005 sbrabec@suse.cz
- Updated to version 2.11.2.
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Fri May 27 2005 sbrabec@suse.cz
- Removed obsolete PKG_CONFIG_PATH line.
* Wed May 18 2005 sbrabec@suse.cz
- Updated to version 2.10.1.
* Tue Mar 22 2005 clahey@suse.de
- Fixes the bug where Places->Connect to server doesn't work
  properly with SSH.
* Mon Mar 21 2005 hhetter@suse.de
- create .hidden if it does not exist on startup to hide some
  kde services (#58875)
* Mon Mar 14 2005 clahey@suse.de
- Remove nautilus-background-memory.patch.  Fixes 72063.
* Wed Mar  9 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Mon Mar  7 2005 gekker@suse.de
- Add nautilus-background-memory.patch
* Fri Mar  4 2005 gekker@suse.de
- Update to version 2.9.92
* Fri Feb 11 2005 gekker@suse.de
- Update to 2.9.91
- Remove upstreamed libexif patch
* Mon Feb  7 2005 gekker@suse.de
- Update to version 2.9.90
* Mon Feb  7 2005 ro@suse.de
- added gnome-menus to neededforbuild
* Tue Feb  1 2005 ro@suse.de
- fix last change
* Mon Jan 31 2005 ro@suse.de
- create directory in build-root before packaging
* Fri Jan 28 2005 sbrabec@suse.cz
- Packaged empty directory for extensions.
* Wed Jan 19 2005 clahey@suse.de
- Updated to version 2.9.2.
* Sun Jan 16 2005 schwab@suse.de
- Fix requires.
* Thu Dec 16 2004 hvogel@suse.de
- fix filelist
* Thu Dec 16 2004 hvogel@suse.de
- require gnome-icon-theme for the desktop file icons
* Wed Dec 15 2004 hvogel@suse.de
- fix desktop file
* Tue Nov 23 2004 hhetter@suse.de
- require gnome2-user-docs (#48272)
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Mon Nov  1 2004 mmj@suse.de
- Locale rename no to nb
* Tue Oct 19 2004 sbrabec@suse.cz
- Fixed support for libexif > 0.5.12.
  http://bugzilla.gnome.org/show_bug.cgi?id=143743
* Tue Oct 12 2004 sbrabec@suse.cz
- Fixed libexecdir for bi-arch (#47050).
* Tue Oct  5 2004 hhetter@suse.de
- register more nautilus desktop files (#46811)
* Mon Oct  4 2004 clahey@suse.de
- Updated string in browser-pref patch.
* Wed Sep 29 2004 sbrabec@suse.cz
- Implemented Open button for mime check warning (#46070),
* Wed Sep 29 2004 hhetter@suse.de
- fix Computer to drives location
* Tue Sep 21 2004 hhetter@suse.de
- show "drives:" location instead of "computer:" and recognize
  /var/lib/Desktop
* Wed Sep  8 2004 clahey@suse.de
- Added OnlyShowIn=GNOME;.
* Tue Aug 24 2004 dave@suse.de
- Added nautilus-location-crash.patch, ximian bug #63445
* Thu Aug 19 2004 dave@suse.de
- Added nautilus-submount.patch, fixes ximian bug #63101
* Tue Aug 17 2004 dave@suse.de
- Added nautilus-startup-notify.patch, fixes ximian bug #62605
* Thu Aug 12 2004 dave@suse.de
- Added patches:
  nautilus-hide-desktop-files.patch - Update of
    nautilus-hide-separators.patch, fixes ximian bug #62339
  nautilus-trim-desktop-menu.patch - fixes ximian bug #59110
* Thu Jul 29 2004 dave@suse.de
- Added patches:
  nautilus-desktop-keybindings.patch
  nautilus-hide-separators.patch
  nautilus-name-length.patch
  nautilus-netscape-url-dnd-format.patch
* Tue Jun 22 2004 dave@suse.de
- Added nautilus-view-dispose.patch
* Thu Jun 17 2004 dave@suse.de
- Updated to nautilus-2.6.3
* Fri Jun  4 2004 clahey@suse.de
- Updated to nautilus-2.6.2.
* Tue May 11 2004 clahey@suse.de
- Added mailto patch.
* Tue May  4 2004 sbrabec@suse.cz
- Updated to version 2.6.1 (GNOME 2.6).
* Fri Apr  2 2004 hhetter@suse.de
- add drives:// to the uri schemes (Bug Id#37848)
* Thu Apr  1 2004 hhetter@suse.de
- nautilus-uri-schemes.dif: add yast-settings:// and suse-menu://
  to the list of uris which desktop files are interpreted
  (Bug Id#37848)
* Mon Mar 22 2004 sbrabec@suse.cz
- Provide and obsolete nautilus2-devel.
* Mon Mar 15 2004 hhetter@suse.de
- install MyComputer Icon on first user startup
* Wed Mar 10 2004 sbrabec@suse.cz
- Fixed gconf schemas installation (#33114).
* Wed Mar  3 2004 hhetter@suse.de
- remove control-center2 from #neededforbuild
* Wed Feb 25 2004 hhetter@suse.de
- apply nautilus-config-defaults.patch: start with sidebar
  disabled, disable sound preview
- remove deprecated filesharing patch
* Fri Feb 20 2004 sbrabec@suse.cz
- Package renamed to nautilus.
* Thu Feb 12 2004 hhetter@suse.de
- gconf schema (de-)installation in %%post and %%postun
* Mon Feb  9 2004 hhetter@suse.de
- updated to version 2.4.2 [GNOME2.4.2]
- cs-typo patch has gone upstream, removed
* Sat Jan 10 2004 adrian@suse.de
- let -devel package require libgnomeui-devel
* Mon Oct 27 2003 sbrabec@suse.cz
- Updated to version 2.4.1.
* Fri Oct 24 2003 sbrabec@suse.cz
- Fill start-here:// with more usable items.
* Tue Oct 21 2003 sbrabec@suse.cz
- Typo fix (cs.po).
* Tue Oct  7 2003 sbrabec@suse.cz
- Updated to version 2.4.0 (GNOME 2.4).
* Mon Sep 22 2003 sbrabec@suse.cz
- Obsolete medusa1.
* Wed Sep 17 2003 kukuk@suse.de
- Replace nautilus
* Sun Sep  7 2003 adrian@suse.de
- add Categories
* Mon Aug 25 2003 hhetter@suse.de
- add filesharing patches
- add filesharing setup tool
* Tue Aug 19 2003 sbrabec@suse.cz
- Updated neededforbuild (rename of librsvg2, eel2).
* Mon Jul 14 2003 sbrabec@suse.cz
- Fixed aclocal command.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Wed Jun 25 2003 sbrabec@suse.cz
- Updated to version 2.2.4.
- Updated neededforbuild.
- Turned on cdparanoia interface.
- Fixed unpackaged files.
- Packaged more docs.
- Require control-center2.
- Use %%find_lang.
* Wed Mar 19 2003 hhetter@suse.de
- updated to version 2.2.2
* Tue Feb 25 2003 hhetter@suse.de
- launch nautilus with --no-desktop in desktop files
  to prevent it from overtaking the desktop in other environments
  as GNOME (#24105)
* Thu Feb 20 2003 hhetter@suse.de
- remove the starthere - link hack which was only for
  2.0.x versions of nautilus
* Thu Feb 13 2003 sbrabec@suse.cz
- Updated to version 2.2.1.
* Mon Feb  3 2003 ro@suse.de
- added startup-notification to neededforbuild
* Wed Jan 29 2003 hhetter@suse.de
- updated to version 2.2.0.2
* Mon Jan 20 2003 ro@suse.de
- update to 2.1.91
* Mon Dec 16 2002 sbrabec@suse.cz
- FHS fix.
- Updated %%files.
- Quick fix of starthere icon look.
* Thu Dec 12 2002 sbrabec@suse.cz
- Added /media path patch (fixes desktop icon look for removable
  devices).
* Fri Nov 29 2002 hhetter@suse.de
- updated to version 2.0.8 [GNOME 2.0.3]
* Thu Oct 24 2002 hhetter@suse.de
- applied new ja-patch from mfabian (partly upstream)
- updated to version 2.0.7
* Mon Oct 21 2002 mfabian@suse.de
- fix corrupted character in ja.po
* Tue Sep 24 2002 sbrabec@suse.cz
- Added alsa-devel to neededforbuild, because esound-devel can require it.
* Thu Sep 19 2002 sbrabec@suse.cz
- Added alsa to neededforbuild, because esound can depend on it.
* Tue Sep 17 2002 hhetter@suse.de
- added better hu po-file from tvamosi
* Tue Sep 17 2002 hhetter@suse.de
- fix hungarian translation
* Tue Aug 20 2002 hhetter@suse.de
- added PreReq: filesystem
* Tue Aug  6 2002 hhetter@suse.de
- updated to version 2.0.3
  * Drag and drop has been implemented in the list view.
  * Performance enhancements in the icon factory.
  * Various bugfixes.
* Sat Jul 27 2002 adrian@suse.de
- fix neededforbuild
- use %%run_ldconfig
* Fri Jul 26 2002 hhetter@suse.de
- updated to version 2.0.2
  * List view does not hang anymore
  * reflect changes in eel 2.0.2 (background api)
  * fix crash when invoking nautilus -q"
* Thu Jul 25 2002 hhetter@suse.de
- fix filelist
* Tue Jul 23 2002 hhetter@suse.de
- updated to version 2.0.1
  * Various UI cleanups from the ui review
  * Various bugfixes
  * The Gnome Nautilus theme now follows the gtk+ theme
  better
  * Window geometry is stored even in
  open-directories-in-same-window
  * All executable bonobo components moved into libexec.
  * Some performance improvements
  * Accessibility fixes
  * Add support for kernel supermount patch
  * Read desktop file icons according to the icon theme
  specification
  * New throbber for the gnome theme
  * large version of trash icon
  * Better handling of disk ejecting
  * Proper handling of launching desktop files according
  to the spec
* Thu Jun 20 2002 hhetter@suse.de
- don't install schemas while make install
* Fri Jun 14 2002 hhetter@suse.de
- filelist lookover
- supply schema file
* Tue Jun 11 2002 hhetter@suse.de
- updated to version 2.0.0
* Fri Jun  7 2002 hhetter@suse.de
- gnome-common in #neededforbuild
* Fri Jun  7 2002 hhetter@suse.de
- really build nautilus treeview and notes
* Wed Jun  5 2002 ro@suse.de
- fix libdir usage
* Wed Jun  5 2002 hhetter@suse.de
- added missing pkgtool files
* Wed Jun  5 2002 hhetter@suse.de
- updated to version 1.1.19, source frozen
- seperation from mozilla and gtkhtml modules
* Wed May 22 2002 meissner@suse.de
- changed neededforbuild so we can run autoconf/aclocal, also added
  libjpeg.
- %%_lib fixes.
* Tue May  7 2002 ro@suse.de
- up to 1.1.15
- added gail to neededforbuild (for eel2)
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Thu Jan 24 2002 hhetter@suse.de
- initial SuSE package for GNOME 2.0 platform
